#
# spec file for package opera
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global __provides_exclude_from ^%{_libdir}/opera/.*\\.so.*$
# libffmpeg.so*, libfreetype.so* and libGLESv2.so* are currently bundled.
%global __requires_exclude ^lib(ffmpeg|freetype|GLESv2)\\.so.*$
Name:           opera
Version:        96.0.4693.31
Release:        lp154.2.44.1
Summary:        Proprietary web browser
License:        NonFree
Group:          Productivity/Networking/Web/Browsers
URL:            https://opera.com/
Source:         https://get.geo.opera.com/ftp/pub/%{name}/desktop/%{version}/linux/%{name}-stable_%{version}_amd64.rpm
Source1:        %{name}.sh.in
Source2:        com.opera.opera.appdata.xml
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files
BuildRequires:  xz
Recommends:     ffmpeg
ExclusiveArch:  x86_64

%description
Opera is a proprietary, fast, and user-friendly web browser.
It includes web developer tools, news aggregation, and the ability
to compress data via Opera Turbo on congested networks.

%prep
rpm2cpio %{SOURCE0} | cpio -i -d

cp -f %{SOURCE2} com.opera.opera.appdata.xml

chmod -s .%{_libdir}/%{name}/%{name}_sandbox
sed -i 's/^\(TargetEnvironment\)/X-\1/' .%{_datadir}/applications/%{name}.desktop

sed \
  -e 's|__LIBDIR__|%{_libdir}|g' \
  -e 's|__SYSCONFDIR__|%{_sysconfdir}|g' \
  %{SOURCE1} > %{name}.sh
cat > %{name}.conf << EOF
# Default settings for opera. This file is sourced by /usr/bin/opera.

# Options to pass to opera.
OPERA_FLAGS=""
EOF

%build
# Nothing to build.

%install
mkdir -p %{buildroot}%{_libdir}/
cp -a .%{_libdir}/%{name} %{buildroot}%{_libdir}/%{name}
install -Dpm 0755 %{name}.sh %{buildroot}%{_bindir}/%{name}

install -Dpm 0644 .%{_datadir}/applications/%{name}.desktop \
  %{buildroot}%{_datadir}/applications/com.opera.opera.desktop
cp -a .%{_datadir}/icons/ %{buildroot}%{_datadir}/

install -Dpm 0755 %{name}.sh %{buildroot}%{_bindir}/%{name}
install -Dpm 0644 %{name}.conf %{buildroot}%{_sysconfdir}/default/%{name}

# https://en.opensuse.org/openSUSE:AppStore
%if 0%{?suse_version} >= 1500
install -Dpm 0644 com.opera.opera.appdata.xml \
  %{buildroot}%{_datadir}/metainfo/com.opera.opera.appdata.xml
%else
install -Dpm 0644 com.opera.opera.appdata.xml \
  %{buildroot}%{_datadir}/appdata/com.opera.opera.appdata.xml
%endif

%fdupes %{buildroot}%{_libdir}/

%files
%config(noreplace) %{_sysconfdir}/default/%{name}
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_datadir}/applications/com.opera.opera.desktop
%{_datadir}/icons/hicolor/*/apps/*
%if 0%{?suse_version} >= 1500
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/com.opera.opera.appdata.xml
%else
%dir %{_datadir}/appdata/
%{_datadir}/appdata/com.opera.opera.appdata.xml
%endif

%changelog
* Thu Mar  2 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to 96.0.4693.31
  * CHR-9206 Update Chromium on desktop-stable-110-4693 to
    110.0.5481.178
  * DNA-104492 [Stable A/B Test] React Start Page for Austria 50%%
  * DNA-104660 Browser crash when calling window.opr.authPrivate
    API in a private mode
  * DNA-105000 Crash at non-virtual thunk to
    SadTabView::OnBoundsChanged(gfx::Rect const&)
  * DNA-105138 Hang-up button is red in video popout
  * DNA-105211 Johnny5 – Prepare extension to be usable in Desktop
  * DNA-105377 Add API for extension to be able to open sidebar
    panel
  * DNA-105378 Add "AI Shorten" functionality to search/copy
    tooltip
  * DNA-105410 Change Popup functionality depending on number
    of words selected
  * DNA-105429 Fix privileges for Shodan api
  * DNA-105434 Change popup depending on number of words
  * DNA-105442 Fix Update & Recovery page styling
  * DNA-105455 [Search box] Search box does not resize dynamically
  * DNA-105606 Enabling news by default on SP test- 2
- The update to chromium 110.0.5481.178 fixes following issues:
  CVE-2023-0927, CVE-2023-0928, CVE-2023-0929, CVE-2023-0930,
  CVE-2023-0931, CVE-2023-0932, CVE-2023-0933, CVE-2023-0941
* Fri Feb 24 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to 96.0.4693.20
  * CHR-9191 Update Chromium on desktop-stable-110-4693 to
    110.0.5481.78
  * CHR-9197 Update Chromium on desktop-stable-110-4693 to
    110.0.5481.100
  * DNA-105308 Translations for O96
  * DNA-105395 Fix missing resources errors on About and
    Update & Recovery pages
- Complete Opera 96.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-96/
- The update to chromium 110.0.5481.78 fixes following issues:
  CVE-2023-0696, CVE-2023-0697, CVE-2023-0698, CVE-2023-0699,
  CVE-2023-0700, CVE-2023-0701, CVE-2023-0702, CVE-2023-0703,
  CVE-2023-0704, CVE-2023-0705
* Wed Feb 15 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to 95.0.4635.46
  * DNA-104601 Crash at
    opera::EasyShareButtonControllerTabHelper::StartOnboarding()
  * DNA-104936 Set new Baidu search string
  * DNA-105084 Prepare to turning on 'Rich entities'
* Thu Feb  9 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to 95.0.4635.37
  * DNA-104366 Turn #speed-dial-custom-image on developer
  * DNA-104370 Pictures in news don’t show
  * DNA-104384 [News] Change News to be disabled by default
  * DNA-104393 [Continue on] Weird look of item counter in
    collapsed Continue shopping after refreshing page
  * DNA-104394 [Continue on] Continue shopping show up collapsed
  * DNA-104421 Mechanism to detect installed player
  * DNA-104439 Merge with GX implementation
  * DNA-104492 [Stable A/B Test] React Start Page for Austria 50%%
  * DNA-104523 [Add to Opera][Folders][Edit] Black font on dark
    background in modals when light theme with dark wallpaper
    is selected
  * DNA-104525 [Choose language and country] Modal does not
    adapt when wallpaper does not match theme
  * DNA-104609 [SD][Folders] Incorrect order of tiles in folder
    when merging folder with single tile
  * DNA-104612 [News] Invisible button in news category.
  * DNA-104614 Do not allow to create folder with the same name
    to prevent automerging
  * DNA-104898 [Edit tile] Adjust icon size of tile in
    edit-form-modal
* Wed Feb  1 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to 95.0.4635.25
  * CHR-9173 Update Chromium on desktop-stable-109-4635 to
    109.0.5414.120
  * DNA-104150 Turn on #consent-flow-settings on master
  * DNA-104733 Crash at
    extensions::SyncPrivateGetSyncStateFunction::Run()
  * DNA-104761 Translations for O95
  * DNA-104814 [StartPage] Inline autocomplete messes up selection
  * DNA-104887 Promote O95 to stable
  * DNA-104908 Enable #consent-flow-settings on all streams
- Complete Opera 95.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-95/
- The update to chromium 109.0.5414.120 fixes following issues:
  CVE-2023-0471, CVE-2023-0472, CVE-2023-0473, CVE-2023-0474
* Thu Jan 19 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to 94.0.4606.76
  * DNA-104276 News categories layers messed up in other languages
* Thu Jan 12 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to 94.0.4606.65
  * DNA-102726 [SD][Folder] When trying to drop SD from folder
    back to folder, new folder is created
  * DNA-102730 [SD][Add to Opera] Remove strip at the top of modal
    and move 'x' button to be in line with ‘Add to Opera' text
  * DNA-102732 [SD][Folders] Add option to merge folders by
    drag and drop
  * DNA-102747 [SD][Folders] Empty SD folder is not visible
  * DNA-102763 [SD] Animate changing between Use bigger tiles
    on and off
  * DNA-102847 [SD][Folders] SD displayed on folder tile should
    be aligned to left
  * DNA-102855 [SD] Add SD by drag and dropping link
  * DNA-102882 [SD][News][Continue on][Suggestion] Do not focus on
    opened page when opening in new tab
  * DNA-102936 [News Categories] Categories become invisible after
    minimizing browser window
  * DNA-102988 [News categories] Only games category displayed
    after changing browser language
  * DNA-103000 [News Categories] Selected categories not saved
    after restarting browser
  * DNA-103001 [News Categories] 'x' button invisible in
    'Choose language and country' on light theme
  * DNA-103002 [News Categories] Changes in 'Choose language and
    country' modal not saved on esc or clicking outside of modal
  * DNA-103015 [News locales] Pref startpage.news_locales udated
    only when close/done the moda, initial value not set
  * DNA-103097 [Settings] Enable 'Adjust Speed Dial animations for
    slower hardware' settings option to have effect
  * DNA-103098 [SD] No big icon for decathlon.pl
  * DNA-103110 Strange animation when dragging tiles
  * DNA-103112 [Continue on] Offers opened on current tab
  * DNA-103116 [Continue on] Not possible to drag tiles from continue
    on section
  * DNA-103131 [Feedback] Implement 'Rate Opera' element and modal
  * DNA-103193 [SD][Edit] Set OK button to read only when typed
    in address is invalid
  * DNA-103293 [SD][Add to Opera] '/' added in autocomplete for URL
  * DNA-103360 [SD][Add to Opera] Tile graphic does not update
    automatically when adding suggestion through Add to Opera modal
  * DNA-103393 [Continue on] Start page needs to be reloaded in
    order to show "Continue on" section
  * DNA-103545 [Banner] Wide banner have no background
  * DNA-103550 [Banners] Black Friday deals promoted on Start
    Page with related settings off
  * DNA-103569 No margin under suggested speed dials
  * DNA-103578 [SD] Impressions should be reported every time user
    comes back to start page tab
  * DNA-103593 [Navigation] Change which elements on start page
    are possible to navigate through with keyboard shortcuts
  * DNA-103595 [Navigation] Show which element is focused when
    navigating with keyboard shortcuts
  * DNA-103605 Dark stripe blinks in Speed Dial Search box when
    changing color mode
  * DNA-103618 [SD][Folder] Not possible to drag SD into
  empty folder
  * DNA-103619 [SD][Suggestions] Blue border on tile when it is
    being dragged
  * DNA-103678 Font modification from themes not applied
  * DNA-103723 [SD][Folders][Edit] Confirm change to SD folder
    name with Enter key
  * DNA-103738 Disable Updater diagnostic metrics that surpass
    session lifetime and verify if it solves DNA-102940
  * DNA-103739 Try to record metrics disabled in DNA-103738 in
    histograms.
  * DNA-103759 [SD][Add to Opera] Wrong position of Add to
    Opera button
  * DNA-103781 [News Categories] Choose language and country shows
    options in 2 columns instead of adapting to wider window
  * DNA-103787 [Continue on] No margin between search box and
    continue on section
  * DNA-103908 [Search box] Blurred text in search box suggestions
    in dark theme
  * DNA-103909 [SD] Not possible to drop SD in empty place when
    hovering over edge of other tile
  * DNA-103911 [SD][Add to Opera] Modal dialog stays open after
    adding suggestion to SD
  * DNA-103915 [SD][Folders] Difficult to drop SD from start page
    between SD in folder
  * DNA-103932 [SD][Add to Opera] Remove https://www and / from
    tile title when adding SD
  * DNA-103933 [SD][Add to Opera] Do not return focus to the end
    of the URL after pressing backspace when editing it
  * DNA-104005 Change activation pop-up
  * DNA-104035 [SD] Browser crashes when dragging tiles with
    fresh profile
  * DNA-104040 Can not drag tile to open folder
  * DNA-104049 Can not drag suggestion when only [+] tile and
    no speed dials
  * DNA-104053 Right mouse click open speed dial instead of
    context menu
  * DNA-104055 News article opens in active tab
  * DNA-104080 Tab not activated after opening speed dial folder
    in new tabs
  * DNA-104088 Create new welcome pop-up for Rich Hints
  * DNA-104139 [Weather] Long time to load Weather widget after
    browser was running for some time
  * DNA-104141 [News] Improve news loading UX
  * DNA-104167 Add feature flag #speed-dial-custom-image
  * DNA-104168 Allow setting custom image for Speed Dial
  * DNA-104196 [News Categories] News categories do not work
  * DNA-104201 Set back Baidu as default search engine in China
  * DNA-104218 [Search box] Search engine icon does not change
  * DNA-104251 Add option to reset to default icon
  * DNA-104256 [Suggestions][ContinueOn][AMG] Scroll button does
    not update its visibility when resizing window
  * DNA-104313 Search bar on Speed Dials doesn't fit it size
  * DNA-104382 Shopping corner is unredible in light theme and
    dark wallpaper
- Changes in 94.0.4606.54
  * CHR-1854 Run gn hooks in gyp_chromium
  * DNA-102035 [Settings] Shortcut search does not work
  * DNA-103451 Add impression and click events for VPN keyword
    suggestion
  * DNA-103643 Prepare for showing Lucid Mode button without text
  * DNA-103675 URL shown for promoted VPN suggestion
  * DNA-104201 Set back Baidu as default search engine in China
  * DNA-104234 Opera update resets all consents to False value
  * DNA-104278 Don’t show Lucid Mode button on videos when hardware
    acceleration is off
* Mon Jan  2 2023 Marko Veelma <marko.veelma@gmail.com>
- Update screenshot URLs in package config
* Thu Dec 22 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 94.0.4606.38
  - CHR-9133 Update chromium on desktop-stable-108-4606 to
    108.0.5359.125
  - DNA-103624 Create JS API to open Search tabs feature
  - DNA-104004 Improve welcome pop-up
  - DNA-104053 Right mouse click open speed dial instead of
    context menu
  - DNA-104055 News article opens in active tab
  - DNA-104084 [Suggestion] Introduce a way to remove the
    Lucid Mode button
  - DNA-104089 No crashes reported in soccoro for Linux
- The update to chromium 108.0.5359.125 fixes following issues:
  CVE-2022-4436, CVE-2022-4437, CVE-2022-4438, CVE-2022-4439,
  CVE-2022-4440
* Fri Dec 16 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 94.0.4606.26
  - CHR-9125 Update chromium on desktop-stable-108-4606 to
    108.0.5359.99
  - DNA-99207 WebUI popup/dropdown could be empty due to lack
    of memory
  - DNA-102882 [SD][News][Continue on][Suggestion] Do not focus
    on opened page when opening in new tab
  - DNA-103076 Release installer consent flow globally
  - DNA-103137 Fix positioning in Web UI component
  - DNA-103240 Re-use logic from popup for consent not set
    in settings
  - DNA-103540 Implement Autostart for Opera Desktop (except Poland)
  - DNA-103636 Implement Lucid Mode for Videos
  - DNA-103637 Implement Lucid Mode button on top of videos
  - DNA-103638 Make Lucid Mode button on top of videos work
  - DNA-103641 Implement Lucid Mode for Images
  - DNA-103642 Updated design and animation for Lucid Mode button
    on top of videos
  - DNA-103650 Add Lucid Mode to Easy Setup
  - DNA-103701 Move User Styles loading/saving to a separate
    component
  - DNA-103718 Record "consent_given" stat for every session
  - DNA-103724 Video detach button wont go away
  - DNA-103757 Add click animation for Lucid Mode button on
    top of videos
  - DNA-103765 Console error with lucid mode flag off
  - DNA-103770 Easy Setup switch doesn't get updated
  - DNA-103771 Click animation should only show when turning
    on Lucid Mode
  - DNA-103773 Unable to access lucid mode settings section
    directly
  - DNA-103784 Investigate video buttons 'escaping'
  - DNA-103800 Adapt Lucid Mode button to new design
  - DNA-103836 Translations for O94
  - DNA-103850 Label on detach button cut off
  - DNA-103924 Popup windows of type TYPE_APP_POPUP have
    incorrectly set minimum size
  - DNA-103931 Wrong sidebar detection.
  - DNA-103935 Change Lucid Mode Video (Sharpen videos) to
    default off
  - DNA-103949 Lucid Mode doesn't work in a private window
  - DNA-103959 Unable to scroll down on player home page
  - DNA-103962 [Settings] Remove "Safety Check"
  - DNA-104011 Turn on Lucid Mode on all streams
  - DNA-104052 Hide Lucid Mode video button on Google Meet
  - DNA-103930 Promote O94 to stable
- Complete Opera 94.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-94/
- The update to chromium 108.0.5359.99 fixes following issues:
  CVE-2022-4262
* Tue Dec 13 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 93.0.4585.64
  - DNA-102836 Make 1st screen of Consent Popup a little taller to
    have more space under "You can adjust your choices…" label
  - DNA-102934 Turn on building testlist on GOTH instead of
    Buildbot
  - DNA-102969 On some pages search popup don't work
  - DNA-103053 Put consent flow settings in separate feature flag
  - DNA-103054 Update consent settings to new design
  - DNA-103062 Add opauto tests for consent flow settings
  - DNA-103099 Set testlist_from in testlist generating script
  - DNA-103240 Re-use logic from popup for consent not set in
    settings
  - DNA-103296 Force dark page break QR code in whats app
  - DNA-103298 Stat for recording adblock whitelist is not sent in
    every session
  - DNA-103522 Missing translations for
    IDS_CONSENT_FLOW_DATA_DESC_INTERESTS
  - DNA-103526 search popup doesn't recognize some currencies
    shortcut
  - DNA-103530 Replace icons in sidebar setup
  - DNA-103636 Implement Lucid Mode for Videos
  - DNA-103637 Implement Lucid Mode button on top of videos
  - DNA-103638 Make Lucid Mode button on top of videos work
  - DNA-103641 Implement Lucid Mode for Images
  - DNA-103642 Updated design and animation for Lucid Mode button
    on top of videos
  - DNA-103650 Add Lucid Mode to Easy Setup
  - DNA-103701 Move User Styles loading/saving to a separate
    component
  - DNA-103718 Record "consent_given" stat for every session
  - DNA-103724 Video detach button wont go away
  - DNA-103757 Add click animation for Lucid Mode button on
    top of videos
  - DNA-103765 Console error with lucid mode flag off
  - DNA-103770 Easy Setup switch doesn't get updated
  - DNA-103771 Click animation should only show when turning on
    Lucid Mode
  - DNA-103773 Unable to access lucid mode settings section
    directly
  - DNA-103784 Investigate video buttons 'escaping'
  - DNA-103800 Adapt Lucid Mode button to new design
  - DNA-103850 Label on detach button cut off
  - DNA-103924 Popup windows of type TYPE_APP_POPUP have
    incorrectly set minimum size
  - DNA-103935 Change Lucid Mode Video (Sharpen videos) to
    default off
  - DNA-104011 Turn on Lucid Mode on all streams
* Thu Dec  1 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 93.0.4585.37
  - DNA-102885 Turn on #sidebar-autohide on all streams
  - DNA-103020 Turn on #start-page-redesign on developer
  - DNA-103042 Fix import from Firefox
  - DNA-103222 [Speed Dial Suggestions] All opera.com subpages
    suggestions lead to the opera.com homepage
  - DNA-103368 TikTok videos starting to play automaticly
  - DNA-103535 Startpage preview is not visible
  - DNA-103665 Reduce Tik Tok pane width
- Changes in 93.0.4585.21
  - CHR-9067 Update chromium on desktop-stable-107-4585 to
    107.0.5304.110
  - DNA-102365 Turn off opera://dify-cards page
  - DNA-102689 [GX] Create GX widgets section in Easy Setup
  - DNA-102768 [Easy setup] Sidebar options not animated
  - DNA-102872 No animation for opening sidebar while sidebar
    is closing
  - DNA-102929 [Weather][Private window] Weather widget appears
    in private window
  - DNA-103032 Messenger sidebar icon doesn’t look great
  - DNA-103046 Opera crash with flag
    –with-feature:sidebar-autohide=off
  - DNA-103107 Automatic video popout for popular sports
    sites – World Cup
  - DNA-103310 hideOperaObject() in browser.js stopped working
    on public builds
  - DNA-103320 Crash at chrome::FindBrowserByType(absl::optional)
  - DNA-103321 Tab preview causes freeze when dragging tabs
  - DNA-103375 [Workspaces] Crash at absl::raw_log_internal::
    RawLog(absl::LogSeverity, char const*, int, char const*, …)
  - DNA-103395 Remove unused resources
  - DNA-103396 Internal translations
- The update to chromium 107.0.5304.110 fixes following issues:
  CVE-2022-3885, CVE-2022-3886, CVE-2022-3887, CVE-2022-3888,
  CVE-2022-3889, CVE-2022-3889
* Thu Nov 17 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 93.0.4585.11
  - CHR-9051 Update chromium on desktop-stable-107-4585 to
    107.0.5304.88
  - DNA-95965 Add support for more UD TLDs
  - DNA-102960 Replace messengers icons
  - DNA-102964 Crash at -[FramedBrowserWindow sendEvent:]
  - DNA-103125 Translations for O93
  - DNA-103287 Bump O93 to stable
- Complete Opera 93.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-93/
- The update to chromium 107.0.5304.88 fixes following issues:
  CVE-2022-3723
* Fri Oct 28 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 92.0.4561.33
  - DNA-102826 Cherry-pick fix for missing dependency in
    aggregation_service
- Changes in 92.0.4561.30
  - DNA-100850 Free VPN confirmation popup in German, button
    covers text
  - DNA-102357 Crash at extensions::
    ProxySwitcherPrivateEventRouter::OnBrowserRemoved(Browser*)
  - DNA-102457 Crash at media_router::
    MediaRouterDialogControllerViews::
    CreateMediaRouterDialog(media_router::
    MediaRouterDialogActivationLocation)
  - DNA-102458 Crash at unsigned
    __int64 std::Cr::__tree<T>::__erase_unique<T>(const void*& const)
  - DNA-102608 Whole text in some translations do not fit in
    consent popup
  - DNA-102693 Privacy Guide section in opera settings
* Mon Oct 24 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 92.0.4561.21
  - CHR-9037 Update chromium on desktop-stable-106-4561 to
    106.0.5249.119
  - DNA-102295 Missing GX.games section in settings
  - DNA-102308 Presubmit errors
  - DNA-102329 [Consent flow] clicking on "Customize settings"
    doesn't resize the popup
  - DNA-102340 Sidebar control panel doesn't hide
  - DNA-102348 Replace old Dify url with a new one
  - DNA-102430 Translations for O92
  - DNA-102534 Allow staging RH Agent extension to use VPN Pro API
  - DNA-102548 Rich hints extension crashes on Linux
  - DNA-102551 Promote O92 to stable
- Complete Opera 92.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-92/
- The update to chromium 106.0.5249.119 fixes following issues:
  CVE-2022-3445, CVE-2022-3446, CVE-2022-3447, CVE-2022-3448,
  CVE-2022-3449, CVE-2022-3450
* Thu Oct 13 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 91.0.4516.77
  - DNA-101988 Implement dark mode for consent flow popups
  - DNA-102348 Replace old Dify url with a new one
* Thu Oct  6 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 91.0.4516.65
  - DNA-101240 Save “remind in 3 days” setting
  - DNA-101622 Add a way to check if browser is connected to webenv
  - DNA-101838 Unfiltered dropdown disabled by default on stable
  - DNA-101990 Boost sites into top sites
  - DNA-101998 flag tiktok-panel doesn’t work
  - DNA-102075 Crash at extensions::ExtensionApiFrameIdMap::
    OnRenderFrameDeleted(content::RenderFrameHost*)
* Wed Sep 21 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 91.0.4516.20
  - CHR-9019 Update chromium on desktop-stable-105-4516 to
    105.0.5195.127
  - DNA-101312 Allow changing logged in user with BrowserAPI
- The update to chromium 105.0.5195.127 fixes following issues:
  CVE-2022-3196, CVE-2022-3197, CVE-2022-3198, CVE-2022-3199,
  CVE-2022-3200, CVE-2022-3201
* Wed Sep 14 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 91.0.4516.16
  - CHR-9010 Update chromium on desktop-stable-105-4516 to
    105.0.5195.102
  - DNA-101447 Incorrect translation in Russian
  - DNA-101482 Crash at ProfileKey::GetProtoDatabaseProvider()
  - DNA-101495 Performance Stint 2022
  - DNA-101551 Add version number info to browser API
  - DNA-101662 Suppress 'Allowing special test code paths'
    warning on buildbot
  - DNA-101753 News don't show after close browser
  - DNA-101760 Translations for O91
  - DNA-101799 Crash at opera::SuggestionList::SortAndCull
  - DNA-101812 Sponsored site gets chosen as default entry
    when typing part of top-level domain
  - DNA-101876 Promote 91 to stable
- Complete Opera 91.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-91/
* Mon Sep 12 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 90.0.4480.107
  - DNA-100664 Shopping corner widget
  - DNA-101495 Performance Stint 2022
  - DNA-101753 News don’t show after close browser
  - DNA-101799 Crash at opera::SuggestionList::SortAndCull
* Tue Sep  6 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 90.0.4480.84
  - DNA-101690 Cherry-pick fix for CVE-2022-3075 from chromium
* Thu Sep  1 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 90.0.4480.80
  - DNA-99188 Tab Tooltip doesn't disappear
  - DNA-100664 Shopping corner widget
  - DNA-100843 Options to install and update VPN Pro app, when
    it's not installed
  - DNA-100901 Disappearing "X" when closing tabs.
  - DNA-101093 Changing News section is not working
  - DNA-101246 Use long tail list for suggesting instead of
    current Speed Dial Suggestions
  - DNA-101278 PDF don't work on Opera with CN location
  - DNA-101312 Allow changing logged in user with BrowserAPI
  - DNA-101315 Can not connect to free VPN in private window
  - DNA-101411 [Linux] Clicking VpnPopup Settings to
    'vpnWithDisclaimer' leads to black popup
  - DNA-101422 Crash at void content::NavigationControllerImpl::
    NavigateToExistingPendingEntry(content::ReloadType, int, bool)
  - DNA-101429 News loads for Global-EN language by default
  - DNA-101482 Crash at ProfileKey::GetProtoDatabaseProvider()
  - DNA-101485 Crash at base::SequencedTaskRunnerHandle::Get()
    via extensions::OperaTouchPrivateGetImageFunction::PerformGetImage
  - DNA-101524 [Mac] Tab should be highlighted again after
    dismissing context menu
  - DNA-101549 Crash at views::View::IsMouseHovered()
* Tue Aug 23 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 90.0.4480.54
  - CHR-8981 Update chromium on desktop-stable-104-4480 to
    104.0.5112.102
  - DNA-98165 [buildsign] Whitelist Silent.nib when creating
    universal NI package on Mac
  - DNA-101309 Use base filename in PUT request when uploading
    files to buildbot
- The update to chromium 104.0.5112.102 fixes following issues:
  CVE-2022-2852, CVE-2022-2854, CVE-2022-2855, CVE-2022-2857,
  CVE-2022-2858, CVE-2022-2853, CVE-2022-2856, CVE-2022-2859,
  CVE-2022-2860, CVE-2022-2861
* Mon Aug 22 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 90.0.4480.48
  - DNA-100835 AddressBarModelTestWithCategories.RefreshUnfiltered
    SuggestionsWhenPrefsChanged fails on beta stream
  - DNA-101171 Translations for O90
  - DNA-101216 Remove empty string from flow client_capabilities
  - DNA-101357 Promote O90 to Stable
  - DNA-101383 Revert DNA-101033
- Complete Opera 90.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-90/
* Mon Aug 15 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 89.0.4447.91
  - DNA-100673 Crash at void
    opera::ModalDialogBaseView::OnExtraButtonPressed
    (const class ui::Event& const)
  - DNA-100915 [Sync Settings] Confirm your identity to enable
    encryption message flickers
  - DNA-100937 Missing links to ToS and Privacy Statement in
    launcher dialog when running installer with –show-eula-window-on-start
  - DNA-101002 Make errors from webpack compilation appear in the log
  - DNA-101045 Popup contents are pushed outside of popup in
    "Unprotected" VPN state
  - DNA-101076 Disabled Pinboards should have another color in
    Account popup
  - DNA-101086 Sync – Clicking Next on
    auth.opera.com/account/v3/desktop/login/confirm-password
    does not redirect anywhere
* Tue Aug  9 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 89.0.4447.83
  - DNA-99507 Badge deactivates on a basket page of the shop
  - DNA-99840 Add speed dials to start page
  - DNA-100127 Enable #enable-force-dark-from-settings on all
    streams
  - DNA-100233 [Settings] "Sync everything" and "Do not sync"
    unselects itself
  - DNA-100560 Add "suggested speed dials" in the Google search box
    on the start page
  - DNA-100568 Fix icon in suggestions and update layout
  - DNA-100646 Add synchronization states to Opera account popup
  - DNA-100665 Create private API to open Account popup + allow
    rich hints
  - DNA-100668 Use a category based suggestion list to sort search
    box suggestions
  - DNA-100701 "Force dark page" shortcut don’t work
  - DNA-100711 Unable to click suggestions on start page search box
  - DNA-100725 [WinLin] Opera account logo is offcenter
  - DNA-100762 Suggestions from networks get favicon from network
  - DNA-100764 Fix "Confirm Identity" URL
  - DNA-100905 Request to update event_sd_tile_used.type
  - DNA-100921 Add accessibility info about sync state to opera
    account button
  - DNA-100943 VPN pro popup can be zoomed
  - DNA-100945 Disable Context Menu for VPN and VPN Pro popups
  - DNA-100958 Opera account popup should display actual state of
    synchronization instead of selected option
  - DNA-100994 "Secure More devices" is pushed outside of popup
  - DNA-101009 Free VPN – "Try for free" disappear after clicked
  - DNA-101012 Remove VPN Pro service available from VPN pro
    settings when logged in without subscription
  - DNA-101094 Unable to close a window from JavaScript
  - DNA-101121 chrome.operaAccountPrivate is undefined
* Thu Jul 28 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 89.0.4447.71
  - CHR-8957 Update chromium on desktop-stable-103-4447 to
    103.0.5060.134
  - DNA-100492 authPrivate.storeCredentials should work with
    running auth session
  - DNA-100649 “Sign out” from settings doesn’t also sign out
    from auth
  - DNA-100653 VPN Badge popup – not working well with different
    page zoom being set in browser settings
  - DNA-100712 Wrong spacing on text to reset sync passphrase
    in settings
  - DNA-100799 VPN icon is “pro” on disconnected
  - DNA-100841 Remove Get Subscription and Get button from
    VPN pro settings
  - DNA-100883 Update missing translations from chromium
  - DNA-100899 Translation error in Turkish
  - DNA-100912 Unable to select pinboards when sync everything
    is enabled
  - DNA-100959 Use after move RecentSearchProvider::ExecuteWithDB
  - DNA-100960 Use after move
    CountryBlacklistServiceImpl::DownloadCountryBlacklist
  - DNA-100961 Use after move
    CategorizationDataCollection::Iterator::Iterator
  - DNA-100989 Crash at
    opera::EasyFileButton::SetThumbnail(gfx::ImageSkia const&)
- The update to chromium 103.0.5060.134 fixes following issues:
  CVE-2022-2163, CVE-2022-2477, CVE-2022-2478, CVE-2022-2479
  CVE-2022-2480, CVE-2022-2481
* Tue Jul 19 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 89.0.4447.51
  - DNA-99538 Typed content of address bar shared between tabs
  - DNA-100418 Set 360 so as search engine in China
  - DNA-100629 Launch Auth login when enabling sync while logged in
  - DNA-100776 Popup is too long if there are no services available
* Thu Jul 14 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 89.0.4447.48
  - CHR-8940 Update chromium on desktop-stable-103-4447 to
    103.0.5060.114
  - DNA-100247 Make it possible to display hint when tab scrolling
    gets triggered
  - DNA-100482 Shopping corner icon availability
  - DNA-100575 Add unique IDs to all web element in opera account
    popup
  - DNA-100625 Opera account popup appears too high on Linux
  - DNA-100627 Enable #snap-from-panel on all stream
  - DNA-100636 DCHECK at suggestion_item.cc(484)
  - DNA-100685 Fix crash when attaching to tab strip scroll buttons
  - DNA-100693 Enable Sticky Site sidebar item to have notification
    bubble
  - DNA-100698 [AdBlock] Unhandled Disconnect list category:
    "emailaggressive"
  - DNA-100716 Misstype Settings "Enhanced address bar"
  - DNA-100732 Fix &amp; escaping in translated strings
  - DNA-100759 Crash when loading personal news in private window
- The update to chromium 103.0.5060.114 fixes following issues:
  CVE-2022-2294, CVE-2022-2295, CVE-2022-2296
* Wed Jul 13 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 89.0.4447.38
  - DNA-100283 Translations for O89
- Complete Opera 89.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-89/
- Changes in 89.0.4447.37
  - CHR-8929 Update chromium on desktop-stable-103-4447 to
    103.0.5060.66
  - DNA-99780 Crash at zmq::zmq_abort(char const*)
  - DNA-100377 New opera account popup doesn’t open on Linux
  - DNA-100589 Crash at base::internal::Invoker<T>::RunOnce
    (base::internal::BindStateBase*, scoped_refptr<T>&&)
  - DNA-100607 Sync “Sign in” button doesn’t work with Opera Account
    popup
* Thu Jul  7 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 88.0.4412.74
  - DNA-100645 Cherry-pick CVE-2022-2294 onto stabilization branches
* Fri Jun 24 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 88.0.4412.53
  - DNA-99108 [Lin] Options on video pop out not possible to change
  - DNA-99832 On automatic video popout, close button should not
    stop video
  - DNA-99833 Allow turning on and off of each 'BABE' section from
    gear icon
  - DNA-99852 Default browser in Mac installer
  - DNA-99993 Crashes in AudioFileReaderTest,
    FFmpegAACBitstreamConverterTest
  - DNA-100045 iFrame Exception not unblocked with Acceptable Ads
  - DNA-100291 Update snapcraft uploading/releasing in scripts to
    use craft store
- Changes in 88.0.4412.40
  - CHR-8905 Update chromium on desktop-stable-102-4412 to
    102.0.5005.115
  - DNA-99713 Sizing issues with video conferencing controls in
    PiP window
  - DNA-99831 Add 'back to tab' button like on video pop-out
- The update to chromium 102.0.5005.115 fixes following issues:
  CVE-2022-2007, CVE-2022-2008, CVE-2022-2010, CVE-2022-2011
- Changes in 88.0.4412.27
  - DNA-99725 Crash at opera::ModalDialogViews::Show()
  - DNA-99752 Do not allow to uncheck all lists for adBlock
  - DNA-99918 Enable #scrollable-tab-strip on desktop-stable-102-4412
  - DNA-99969 Promote O88 to stable
- Complete Opera 88.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-88/
* Thu Jun  2 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 87.0.4390.45
  - DNA-99478 Top Sites don’t always has big icon
  - DNA-99702 Enable Acceptable Ads for stable stream
  - DNA-99725 Crash at opera::ModalDialogViews::Show()
  - DNA-99752 Do not allow to uncheck all lists for adBlock
* Thu May 26 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 87.0.4390.36
  - CHR-8883 Update chromium on desktop-stable-101-4390 to
    101.0.4951.67
  - DNA-99190 Investigate windows installer signature errors on win7
  - DNA-99502 Sidebar – API to open panels
  - DNA-99593 Report sad tab displayed counts per kind
  - DNA-99628 Personalized Speed Dial context menu issue fix
* Tue May 17 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 87.0.4390.25
  - CHR-8870 Update chromium on desktop-stable-101-4390 to
    101.0.4951.64
  - DNA-99209 Enable #easy-files-multiupload on all streams
  - DNA-99325 Use a preference to set number of recent searches and
    recently closed in unfiltered dropdown
  - DNA-99353 Translations for O87
  - DNA-99365 Adding title to the first category duplicates
    categories titles in the dropdown
  - DNA-99385 Feedback button in filtered dropdown can overlap with
    other web buttons for highlighted suggestion
  - DNA-99391 Add bookmarks at the bottom of a bookmarks bar folder
  - DNA-99491 Suggestion is not immediately removed form recent
    searches view in dropdown.
  - DNA-99501 Promote O87 to stable
  - DNA-99504 “Switch to tab” button is not aligned to the right
    for some categories in dropdown
- The update to chromium 101.0.4951.64 fixes following issues:
  CVE-2022-1633, CVE-2022-1634, CVE-2022-1635, CVE-2022-1636,
  CVE-2022-1637, CVE-2022-1638, CVE-2022-1639, CVE-2022-1640,
  CVE-2022-1641
- Complete Opera 87.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-87/
* Wed May 11 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 86.0.4363.59
  - DNA-99021 Crash in sidebar when extension of sidebar item was
    uninstalled
  - DNA-99359 Crash at opera::
    ContinueShoppingExpiredProductRemoverImpl::RemoveExpiredProducts()
* Sun May  8 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 86.0.4363.50
  - DNA-68493 Opera doesn’t close address field drop-down when
    dragging text from the address field
  - DNA-99003 Crash at views::Widget::GetNativeView() const
  - DNA-99133 BrowserSidebarWithProxyAuthTest.PreloadWithWebModalDialog
    fails
  - DNA-99230 Switching search engine with shortcut stopped working
    after DNA-99178
  - DNA-99317 Make history match appear on top
* Wed Apr 27 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 86.0.4363.32
  - DNA-98510 Blank icon in sidebar setup
  - DNA-98525 Unable to drag tab to far right
  - DNA-98893 Sound indicator is too precise in Google Meet
  - DNA-98919 Shopping corner internal API access update
  - DNA-98924 Tab tooltip gets stuck on screen
  - DNA-98981 Enable easy-files-multiupload on developer stream
  - DNA-99041 Move Shopping Corner to sidebar entry
  - DNA-99061 Enable #address-bar-dropdown-categories on all streams
  - DNA-99062 Create flag to show top sites and recently closed in
    unfiltered suggestions
  - DNA-99064 Hard to drag & drop current URL to a specific folder
    on bookmarks bar when unfiltered dropdown is displayed
  - DNA-99070 Make scroll button in Continue On scroll multiple
    items
  - DNA-99089 Shopping corner tab is not preserved after restart
  - DNA-99115 Request updating the Avro schema for sidebar event
  - DNA-99117 Make sure shopping corner is enabled by default
  - DNA-99178 Left/right not working in address bar dropdown
  - DNA-99204 Hide Shopping Corner by default
* Wed Apr 20 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 86.0.4363.23
  - CHR-8843 Update chromium on desktop-stable-100-4363 to
    100.0.4896.127
  - DNA-98236 Turn on #snap-text-selection on all streams
  - DNA-98507 DCHECK at address_bar_controller.cc(547)
  - DNA-98528 Suggestions for internal pages disappear when typing
    their full name
  - DNA-98538 Change name of "Opera Crypto Wallet" to
    "Crypto Wallet"
  - DNA-98540 Booking.com used instead of custom search engine
  - DNA-98587 Favicon of booking suggestion in the city category
    is unexpectedly changing
  - DNA-98605 City suggestions should show URL in address field
    when selected
  - DNA-98608 #address-bar-dropdown-categories expired
  - DNA-98616 Add recent searches to 'old' BABE
  - DNA-98668 Switch to tab button leads to wrong tab
  - DNA-98673 Improve suggestion removal handling in suggestion
    providers
  - DNA-98681 Remove unused suggestion consumers
  - DNA-98684 Have a dedicated SuggestionList for the new address
    bar dropdown
  - DNA-98685 Enable #native-crypto-wallet on developer
  - DNA-98688 "Disable this feature" mini-menu settings is
    non-intuitive
  - DNA-98690 Autocompleted text stayed in address field after
    removing suggestion
  - DNA-98738 Inline autocomplete suggestion for SD disappears
    after typing 3rd letter of SD name
  - DNA-98743 Blank dropdown after pressing space key
  - DNA-98783 Improve showing suggestions with long URLs or page
    titles
  - DNA-98785 "Switch to tab" button not shown for suggestions with
    www subdomain when typing domain text
  - DNA-98879 "Disable suggestions before typing" mini-menu option
    should change to "Enable suggestions before typing" when being
    selected
  - DNA-98917 Translations for O86
  - DNA-98975 Turn on #snap-crop-tool on all channels
  - DNA-98980 Enable #native-crypto-wallet on all streams
  - DNA-99005 The sidebar item is not visible for already active
    crypto wallet users when #native-crypto-wallet flag is enabled.
  - DNA-99007 Crash at
    TemplateURLRef::ParseIfNecessary(SearchTermsData const&) const
  - DNA-99047 Promote O86 to stable
- The update to chromium 100.0.4896.127 fixes following issues:
  CVE-2022-1364
- Complete Opera 86.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-86/
* Thu Apr  7 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 85.0.4341.60
  - DNA-98666 Set baidu as default search engine in China
  - DNA-98707 Hint is not displayed for new crypto wallet
    sidebar icon
  - DNA-98775 RichHintsSearchEngineCondition.testSogouSearchEngine
    errors
* Fri Apr  1 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 85.0.4341.47
  - DNA-98249 Add feature flag #native-crypto-wallet
  - DNA-98250 Install extension on startup
  - DNA-98251 Make Crypto Wallet setting enable / disable extension
  - DNA-98252 Deactivate old desktop crypto wallet
  - DNA-98253 Always show “Crypto Wallet” in Sidebar Setup
  - DNA-98497 Crash when installing extension
  - DNA-98506 Enable opera_feature_crypto_wallet_encryption
    on desktop
  - DNA-98510 Blank icon in sidebar setup
  - DNA-98538 Change name of "Opera Crypto Wallet" to
    "Crypto Wallet"
  - DNA-98685 Enable #native-crypto-wallet on developer
  - DNA-98766 Crash at
    opera::AddressBarControllerImpl::OpenNativeDropdown()
  - DNA-98768 Crash at
    extensions::ContentFilterPrivateIsWhitelistedFunction::Run()
  - DNA-98770 Recent searches stay in address field after selecting
    entry from dropdown
  - DNA-98772 Screen sharing broken
  - DNA-98803 Autofilled part appended after selecting address
    bar using shortcut
* Tue Mar 29 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 85.0.4341.28
  - CHR-8816 Update chromium on desktop-stable-99-4341
    to 99.0.4844.84
  - DNA-98092 Crash at views::MenuItemView::GetMenuController()
  - DNA-98278 Translations for O85
  - DNA-98320 [Mac] Unable to delete recent search entries
  - DNA-98614 Show recent searches for non-BABE users
  - DNA-98615 Allow removal of recent searches
  - DNA-98616 Add recent searches to ‘old’ BABE
  - DNA-98617 Make it possible to disable ad-blocker per-country
  - DNA-98651 Remove Instagram and Facebook Messenger in Russia
  - DNA-98653 Add flag #recent-searches
  - DNA-98696 smoketest
    PageInfoHistoryDataSourceTest.FormatTimestampString failing
  - DNA-98703 Port Chromium issue 1309225 to Opera Stable
- The update to chromium 99.0.4844.84 fixes following issues:
  CVE-2022-1096
- Changes in 85.0.4341.18
  - CHR-8789 Update chromium on desktop-stable-99-4341 to
    99.0.4844.51
  - DNA-98059 [Linux] Crash at
    opera::FreedomSettingsImpl::IsBypassForDotlessDomainsEnabled
  - DNA-98349 [Linux] Crash at bluez::BluezDBusManager::Get()
  - DNA-98126 System crash dialog shown on macOS <= 10.15
  - DNA-98331 [Snap] Meme generator cropping / resizing broken
  - DNA-98394 Audio tab indicator set to "muted" on
    videoconferencing sites
  - DNA-98481 Report errors in opauto_collector
- The update to chromium 99.0.4844.51 fixes following issues:
  CVE-2022-0789, CVE-2022-0790, CVE-2022-0791, CVE-2022-0792,
  CVE-2022-0793, CVE-2022-0794, CVE-2022-0795, CVE-2022-0796,
  CVE-2022-0797, CVE-2022-0798, CVE-2022-0799, CVE-2022-0800,
  CVE-2022-0801, CVE-2022-0802, CVE-2022-0803, CVE-2022-0804,
  CVE-2022-0805, CVE-2022-0806, CVE-2022-0807, CVE-2022-0808,
  CVE-2022-0809
- Changes in 85.0.4341.13
  - DNA-94119 Upgrade curl to 7.81.0
  - DNA-97849 [Mac monterey] System shortcut interfere with
    Opera’s `ToggleSearchInOpenTabs` shortcut
  - DNA-98204 Automatic popout happens when video is paused
  - DNA-98231 Shortcuts are blocked by displayed tab tooltip
    when triggered quickly after tooltip appears
  - DNA-98321 Add thinlto-cache warnings to suppression list
  - DNA-98395 Promote O85 to stable
- Complete Opera 85.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-85/
* Thu Mar 17 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 84.0.4316.42
  - DNA-94119 Upgrade curl to 7.81.0
  - DNA-98092 Crash at views::MenuItemView::GetMenuController()
  - DNA-98204 Automatic popout happens when video is paused
  - DNA-98231 Shortcuts are blocked by displayed tab tooltip when
    triggered quickly after tooltip appears
* Thu Mar  3 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 84.0.4316.31
  - CHR-8772 Update chromium on desktop-stable-98-4316 to
    98.0.4758.109
  - DNA-97573 [Win][Lin]”Close tab” button is not displayed on tabs
    playing media when many tabs are open
  - DNA-97729 cancelling the process uploading custom Wallpaper
    crashes the browser
  - DNA-97871 Google meet tab’s icons don’t fit on pinned tab
  - DNA-97872 Tab is being unpinned when video conferencing
    button is clicked
  - DNA-98039 Dark theme top sites have black background
  - DNA-98117 Clicking current tab information should hide tooltip
* Fri Feb 25 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 84.0.4316.21
  - CHR-8762 Update chromium on desktop-stable-98-4316 to
    98.0.4758.102
  - DNA-97333 ‘Add a site’ label on start page tile barely visible
  - DNA-97691 Opera 84 translations
  - DNA-97767 Wrong string in FR
  - DNA-97855 Crash at
    ScopedProfileKeepAlive::~ScopedProfileKeepAlive()
  - DNA-97982 Enable #snap-upstream-implementation on all streams
- The update to chromium 98.0.4758.102 fixes following issues:
  CVE-2022-0603, CVE-2022-0604, CVE-2022-0605, CVE-2022-0606,
  CVE-2022-0607, CVE-2022-0608, CVE-2022-0609, CVE-2022-0610
* Wed Feb 16 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 84.0.4316.14
  - CHR-8753 Update chromium on desktop-stable-98-4316 to
    98.0.4758.82
  - DNA-97177 Battery saver – the icon looks bad for DPI!=100%%
  - DNA-97614 automatic video pop-out for most popular websites
    broadcasting Winter Olympic Games 2022
  - DNA-97804 Promote O84 to stable
- The update to chromium 98.0.4758.82 fixes following issues:
  CVE-2022-0452, CVE-2022-0453, CVE-2022-0454, CVE-2022-0455,
  CVE-2022-0456, CVE-2022-0457, CVE-2022-0458, CVE-2022-0459,
  CVE-2022-0460, CVE-2022-0461, CVE-2022-0462, CVE-2022-0463,
  CVE-2022-0464, CVE-2022-0465, CVE-2022-0466, CVE-2022-0467,
  CVE-2022-0468, CVE-2022-0469, CVE-2022-0470
- Complete Opera 84.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-84/
* Wed Feb  9 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 83.0.4254.54
  - DNA-96581 Fast tab tooltip doesn’t always show related sites
    with scrollable tab strip
  - DNA-96608 Cannot drag a tab to create a new window
  - DNA-96657 Do not make tab tooltip hoverable if there’s no
    list of tabs
  - DNA-97291 Crash at
    opera::flow::FlowSessionImpl::RegisterDevice(base::OnceCallback)
  - DNA-97468 Incorrect number of restored tabs when video-popout
    is detached
  - DNA-97476 Add retry to stapling during signing
  - DNA-97609 Failing MetricsReporterTest.TimeSpent* smoketests
* Wed Jan 26 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 83.0.4254.27
  - CHR-8737 Update chromium on desktop-stable-97-4254 to
    97.0.4692.99
  - DNA-96336 [Mac] Translate new network installer slogan
  - DNA-96678 Add battery level monitoring capability to
    powerSavePrivate
  - DNA-96939 Crash at
    opera::ExternalVideoService::MarkAsManuallyClosed()
  - DNA-97276 Enable #static-tab-audio-indicator on all streams
- The update to chromium 97.0.4692.99 fixes following issues:
  CVE-2022-0289, CVE-2022-0290, CVE-2022-0291, CVE-2022-0292,
  CVE-2022-0293, CVE-2022-0294, CVE-2022-0295, CVE-2022-0296,
  CVE-2022-0297, CVE-2022-0298, CVE-2022-0300, CVE-2022-0301,
  CVE-2022-0302, CVE-2022-0304, CVE-2022-0305, CVE-2022-0306,
  CVE-2022-0307, CVE-2022-0308, CVE-2022-0309, CVE-2022-0310,
  CVE-2022-0311
* Wed Jan 19 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to 83.0.4254.19
  - DNA-96079 Turn on #automatic-video-popout on developer
  - DNA-97070 Opera 83 translations
  - DNA-97119 [LastCard] Stop showing used burner cards
  - DNA-97131 Enable automatic-video-popout on all streams from
    O84 on
  - DNA-97257 Crash at
    views::ImageButton::SetMinimumImageSize(gfx::Size const&)
  - DNA-97259 Promote O83 to stable
- Complete Opera 83.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-83/
- Update to 83.0.4254.16
  - DNA-96968 Fix alignment of the 'Advanced' button in Settings
- Update to 83.0.4254.14
  - CHR-8701 Update chromium on desktop-stable-97-4254 to
    97.0.4692.45
  - CHR-8713 Update chromium on desktop-stable-97-4254 to
    97.0.4692.56
  - CHR-8723 Update chromium on desktop-stable-97-4254 to
    97.0.4692.71
  - DNA-96780 Crash at
    ui::NativeTheme::RemoveObserver(ui::NativeThemeObserver*)
  - DNA-96822 Tab close resize behavior change
  - DNA-96861 Create Loomi Options menu
  - DNA-96904 Support Win11 snap layout popup
  - DNA-96951 Tab close animation broken
  - DNA-96991 Tab X button doesn’t work correctly
  - DNA-97027 Incorrect tab size after tab close
- The update to chromium 97.0.4692.71 fixes following issues:
  CVE-2022-0096, CVE-2022-0097, CVE-2022-0098, CVE-2022-0099,
  CVE-2022-0100, CVE-2022-0101, CVE-2022-0102, CVE-2022-0103,
  CVE-2022-0104, CVE-2022-0105, CVE-2022-0105, CVE-2022-0106,
  CVE-2022-0107, CVE-2022-0108, CVE-2022-0109, CVE-2022-0110,
  CVE-2022-0111, CVE-2022-0111, CVE-2022-0112, CVE-2022-0113,
  CVE-2022-0114, CVE-2022-0115, CVE-2022-0116, CVE-2022-0117,
  CVE-2022-0118, CVE-2022-0120
* Wed Jan 12 2022 Carsten Ziepke <kieltux@gmail.com>
- Update to version 82.0.4227.58
  - DNA-96780 Crash at
    ui::NativeTheme::RemoveObserver(ui::NativeThemeObserver*)
  - DNA-96890 Settings default browser not working for current
    user on Windows 7
* Tue Dec 21 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 82.0.4227.43
  - CHR-8705 Update chromium on desktop-stable-96-4227 to
    96.0.4664.110
  - DNA-93284 Unstable
    obj/opera/desktop/common/installer_rc_generated/installer.res
  - DNA-95908 Interstitial/internal pages shown as NOT SECURE
    after visiting http site
  - DNA-96404 Opera doesn’t show on main screen when second screen
    is abruptly disconnected
- The update to chromium 96.0.4664.110 fixes following issues:
  CVE-2021-4098, CVE-2021-4099, CVE-2021-4100, CVE-2021-4101,
  CVE-2021-4102
* Wed Dec 15 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 82.0.4227.33
  - CHR-8689 Update chromium on desktop-stable-96-4227 to
    96.0.4664.93
  - DNA-96559 Tooltip popup looks bad in dark theme
  - DNA-96570 [Player] Tidal logging in via PLAY doesn’t work
  - DNA-96594 Unnecessary extra space in fullscreen mode on M1 Pro MacBooks
  - DNA-96649 Update Meme button
  - DNA-96676 Add Icon in the Sidebar Setup
  - DNA-96677 Add default URL
- The update to chromium 96.0.4664.93 fixes following issues:
  CVE-2021-4052, CVE-2021-4053, CVE-2021-4079, CVE-2021-4054,
  CVE-2021-4078, CVE-2021-4055, CVE-2021-4056, CVE-2021-4057,
  CVE-2021-4058, CVE-2021-4059, CVE-2021-4061, CVE-2021-4062,
  CVE-2021-4063, CVE-2021-4064, CVE-2021-4065, CVE-2021-4066,
  CVE-2021-4067, CVE-2021-4068
* Thu Dec  2 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 82.0.4227.23
  - DNA-95632 With new au-logic UUID is set with delay and may be
    not set for pb-builds (when closing fast)
  - DNA-96349 Laggy tooltip animation
  - DNA-96483 [Snap][Linux] Video not working / wrong ffmpeg snap
    version for Opera 82
  - DNA-96493 Create 'small' enticement in credit card autofill
  - DNA-96533 Opera 82 translations
  - DNA-96535 Make the URL configurable
  - DNA-96553 Add switch to whitelist test pages
  - DNA-96557 Links not opened from panel
  - DNA-96558 AdBlock bloks some trackers inside the panel
  - DNA-96568 [Player] Tidal in sidebar Player opens wrong site
    when logging in
  - DNA-96659 Siteprefs not applied after network service crash
  - DNA-96593 Promote O82 to stable
- Complete Opera 82.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-82/
- Update to version 82.0.4227.13
  - CHR-8668 Update chromium on desktop-stable-96-4227 to
    96.0.4664.45
  - DNA-76987 [Mac] Update desktop EULA with geolocation split
  - DNA-93388 Problem with symlinks on windows when creating
    file list
  - DNA-95734 Discarded Recently Closed items get revived
    after restart
  - DNA-96134 "Your profile has been updated" does not disappear
  - DNA-96190 Opera freezes when trying to drag expanded
    bookmark folder with nested subfolders
  - DNA-96223 Easy Files not working in Full Screen
  - DNA-96274 Checkout autofill shouldn't show used burner card
  - DNA-96275 Change the notification message for pausing
    multi-use cards
  - DNA-96295 "Video pop out" setting doesn't sync
  - DNA-96316 Highlight text wrong colour on dark mode
  - DNA-96326 Wrong translation Private Mode > Turkish
  - DNA-96351 macOS window controls are missing in full screen
  - DNA-96440 Update video URL
  - DNA-96448 add option to pin extension via rich hints
  - DNA-96453 Register user-chosen option on client-side, read on
    hint side
  - DNA-96454 Choosing an option from the settings menu should
    close the popup
  - DNA-96484 Enable AB test for a new autoupdater logic (for 50%%)
  - DNA-96500 Add "don't show me again" prefs to allowed whitelist
  - DNA-96538 Inline audiocomplete for www.mediaexpert.pl
    incorrectly suggested
- The update to chromium 96.0.4664.45 fixes following issues:
  CVE-2021-38005, CVE-2021-38006, CVE-2021-38007, CVE-2021-38008,
  CVE-2021-38009, CVE-2021-38010, CVE-2021-38011, CVE-2021-38012,
  CVE-2021-38013, CVE-2021-38014, CVE-2021-38015, CVE-2021-38016,
  CVE-2021-38017, CVE-2021-38019, CVE-2021-38020, CVE-2021-38021,
  CVE-2021-38022
* Wed Nov 17 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 81.0.4196.54
  - CHR-8644 Update chromium on desktop-stable-95-4196 to
    95.0.4638.69
  - DNA-95773 ExtensionWebRequestApiTest crashes on mac
  - DNA-96062 Opera 81 translations
  - DNA-96134 “Your profile has been updated’ does not disappear
  - DNA-96274 Checkout autofill shouldn’t show used burner card
  - DNA-96275 Change the notification message for pausing
    multi-use cards
  - DNA-96440 Update video URL
- The update to chromium 95.0.4638.69 fixes following issues:
  CVE-2021-37997, CVE-2021-37998, CVE-2021-37999, CVE-2021-37980,
  CVE-2021-38001, CVE-2021-38002, CVE-2021-38003, CVE-2021-38004
- Update to version 81.0.4196.37
  - DNA-96008 Crash at
    content::WebContentsImpl::OpenURL(content::OpenURLParams const&)
  - DNA-96032 Closing the videoconference pop-up force leaving
    the meeting
  - DNA-96092 Crash at void
    opera::ModalDialogViews::OnWidgetClosing(opera::ModalDialog::Result)
  - DNA-96142 [Yat] Emoji icon cut off in URL for Yat
* Wed Nov 10 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 81.0.4196.31
  - DNA-95733 Implement the “Manage” menu in card details view
  - DNA-95736 Update UI for paused card
  - DNA-95791 Crash at base::operator<
  - DNA-95794 Sometimes the sidebar UI fails to load
  - DNA-95812 Retrieve cards info when showing autofill
  - DNA-96035 Cannot create virtual card on Sandbox environment
  - DNA-96147 “Buy” button does not work
  - DNA-96168 Update contributors list
  - DNA-96211 Enable #fast-tab-tooltip on all streams
  - DNA-96231 Promote O81 to stable
- Complete Opera 80.1 changelog at:
  https://blogs.opera.com/desktop/changelog-for-81/
- Update to version 81.0.4196.27
  - CHR-8623 Update chromium on desktop-stable-95-4196 to
    95.0.4638.54
  - DNA-92384 Better segmenting of hint users
  - DNA-95523 Allow sorting in multi-card view
  - DNA-95659 Flow of Lastcard on first login
  - DNA-95735 Implement the button that reveals full card
    details
  - DNA-95747 Better way to handle expired funding card
  - DNA-95949 [Mac Retina] Clicking active tab should scroll
    to the top
  - DNA-95993 Update icon used for Yat in address bar dropdown
  - DNA-96021 Cleared download item view is never deleted
  - DNA-96036 Occupation field in 'Account – Edit' is shown
    twice
  - DNA-96127 Upgrade plan button does nothing
  - DNA-96138 "Add Card" button does not change to
    "Upgrade Plan" after adding card
- The update to chromium 95.0.4638.54 fixes following issues:
  CVE-2021-37981, CVE-2021-37982, CVE-2021-37983, CVE-2021-37984,
  CVE-2021-37985, CVE-2021-37986, CVE-2021-37987, CVE-2021-37988,
  CVE-2021-37989, CVE-2021-37990, CVE-2021-37991, CVE-2021-37992,
  CVE-2021-37993, CVE-2021-37994, CVE-2021-37995, CVE-2021-37996
* Thu Oct 28 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 80.0.4170.72
  - DNA-95522 Change card view to show all types of cards
  - DNA-95523 Allow sorting in multi-card view
  - DNA-95524 Allow searching for cards by name
  - DNA-95658 Allow user to add a card
  - DNA-95659 Flow of Lastcard on first login
  - DNA-95660 Implement editing card details
  - DNA-95699 Add card details view
  - DNA-95733 Implement the “Manage” menu in card details view
  - DNA-95735 Implement the button that reveals full card details
  - DNA-95736 Update UI for paused card
  - DNA-95747 Better way to handle expired funding card
  - DNA-95794 Sometimes the sidebar UI fails to load
  - DNA-95812 Retrieve cards info when showing autofill
  - DNA-96036 Occupation field in ‘Account – Edit’ is shown twice
  - DNA-96127 Upgrade plan button does nothing
  - DNA-96138 “Add Card” button does not change to “Upgrade Plan”
    after adding card
* Fri Oct 22 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 80.0.4170.63
  - CHR-8612 Update chromium on desktop-stable-94-4170 to
    94.0.4606.81
  - DNA-95434 Crash at opera::ThemesService::UpdateCurrentTheme()
- The update to chromium 94.0.4606.81 fixes following issues:
  CVE-2021-37977, CVE-2021-37978, CVE-2021-37979, CVE-2021-37980
* Fri Oct 15 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 80.0.4170.40
  - CHR-8598 Update chromium on desktop-stable-94-4170 to
    94.0.4606.71
  - DNA-95221 Emoji button stuck in address bar
  - DNA-95325 Make y.at navigations to be reported with
    page_views events
  - DNA-95327 Add “Emojis” context menu option in address
    bar field
  - DNA-95339 Add YAT emoji url suggestion to search© dialog
  - DNA-95416 Remove emoji button from address bar
  - DNA-95439 Enable #yat-emoji-addresses on developer stream
  - DNA-95441 [Mac big sur] Emoji are not shown in address
    bar url
  - DNA-95514 Crash at resource_coordinator::TabLifecycleUnitSource
    ::TabLifecycleUnit::OnLifecycleUnitStateChanged(mojom::
    LifecycleUnitState, mojom::LifecycleUnitStateChangeReason)
  - DNA-95746 Enable #reader-mode everywhere
  - DNA-95865 Numbers are recognized as emojis
  - DNA-95866 Change Yat text in selection popup
  - DNA-95867 Show that buttons are clickable in selection popup
- The update to chromium 94.0.4606.71 fixes following issues:
  CVE-2021-37974, CVE-2021-37975, CVE-2021-37976
* Fri Oct  8 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 80.0.4170.16
  - CHR-8590 Update chromium on desktop-stable-94-4170
    to 94.0.4606.61
  - DNA-95347 Make InstallerStep::Run async
  - DNA-95420 First suggestion in address field is often not
    highlighted
  - DNA-95613 Browser closing itself after closing SD/first tab
    and last opened tab
  - DNA-95725 Promote O80 to stable
  - DNA-95781 Import fixes for CVE-2021-37975, CVE-2021-37976 and
    CVE-2021-37974 to desktop-stable-94-4170
- Complete Opera 80.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-80/
- Drop Provides/Obsoletes for opera-gtk and opera-kde4
  opera-gtk and opera-kde4 were last used in openSUSE 13.1
- Drop post/postun for desktop_database_post and
  icon_theme_cache_post because were last used before
  openSUSE 15.0
* Wed Sep 29 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 79.0.4143.72
  - DNA-94933 Add emoji panel to address bar
  - DNA-95210 Add emoji YAT address bar suggestions
  - DNA-95221 Emoji button stuck in address bar
  - DNA-95325 Make y.at navigations to be reported with page_views
    events
  - DNA-95327 Add “Emojis” context menu option in address bar field
  - DNA-95339 Add YAT emoji url suggestion to search© dialog
  - DNA-95364 Add browser feature flag
  - DNA-95416 Remove emoji button from address bar
  - DNA-95439 Enable #yat-emoji-addresses on developer stream
  - DNA-95441 [Mac big sur] Emoji are not shown in address bar url
  - DNA-95445 Crash when removing unsynced pinboard bookmark with
    sync enabled
  - DNA-95512 Allow to show title and timer for simple banners
  - DNA-95516 Wrong label in settings for themes
  - DNA-95679 Temporarily disable AB test for a new autoupdater
    logic
* Tue Sep 21 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 79.0.4143.50
  - CHR-8571 Update chromium on desktop-stable-93-4143
    to 93.0.4577.82
  - DNA-94104 ContinueShoppingOnEbayBrowserTest.ShouldDisplayOffers
    TilesStartingWithMostActiveOnes fails
  - DNA-94894 [Rich Hint] Agent API permissions
  - DNA-94989 Wrong color and appearance of subpages in the settings
  - DNA-95241 “Switch to tab” button is visible only on hover
  - DNA-95286 Add unit tests to pinboard sync related logic in browser
  - DNA-95372 [Mac retina screen] Snapshot doesnt capture cropped area
  - DNA-95526 Some webstore extensions are not verified properly
- The update to chromium 93.0.4577.82 fixes following issues:
  CVE-2021-30625, CVE-2021-30626, CVE-2021-30627, CVE-2021-30628,
  CVE-2021-30629, CVE-2021-30630, CVE-2021-30631, CVE-2021-30632,
  CVE-2021-30633
* Tue Sep 14 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 79.0.4143.22
  - CHR-8550 Update chromium on desktop-stable-93-4143 to
    93.0.4577.58
  - CHR-8557 Update chromium on desktop-stable-93-4143 to
    93.0.4577.63
  - DNA-94641 [Linux] Proprietary media codecs not working in
    snap builds
  - DNA-95076 [Linux] Page crash with media content
  - DNA-95084 [Mac] Cannot quit through menu with snapshot
    editor open
  - DNA-95138 Add setting to synchronize Pinboards
  - DNA-95157 Crash at -[OperaCrApplication sendEvent:]
  - DNA-95204 Opera 79 translations
  - DNA-95240 The pinboard thumbnail cannot be generated anymore
  - DNA-95278 Existing Pinboards might be missing
  - DNA-95292 Enable #bookmarks-trash-cleaner on all streams
  - DNA-95293 Enable #easy-files-downloads-folder on all streams
  - DNA-95383 Promote O79 to stable
- Complete Opera 79.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-79/
- The update to chromium 93.0.4577.58 fixes following issues:
  CVE-2021-30606, CVE-2021-30607, CVE-2021-30608, CVE-2021-30609,
  CVE-2021-30610, CVE-2021-30611, CVE-2021-30612, CVE-2021-30613,
  CVE-2021-30614, CVE-2021-30615, CVE-2021-30616, CVE-2021-30617,
  CVE-2021-30618, CVE-2021-30619, CVE-2021-30620, CVE-2021-30621,
  CVE-2021-30622, CVE-2021-30623, CVE-2021-30624
* Wed Aug 25 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 78.0.4093.184
  - CHR-8533 Update chromium on desktop-stable-92-4093 to
    92.0.4515.159
  - DNA-93472 Reattaching to other browsers
  - DNA-93741 Multiple hint slots
  - DNA-93742 Allow displaying unobtrusive external hints
  - DNA-93744 Add slots in toolbar action view
  - DNA-94230 Improve text contrast for Speed Dials
  - DNA-94724 [Mac] Add macOS dark theme wallpaper with easy setup
  - DNA-94786 Crash at base::SupportsUserData::
    SetUserData(void const*, std::__1::unique_ptr)
  - DNA-94807 Allow scripts access opera version and product info
  - DNA-94862 Continue on shopping Amazon doesn’t work correct
  - DNA-94870 Add an addonsPrivate function to install with
    permissions dialog first
  - DNA-95064 Revert DNA-93714 on stable
- The update to chromium 92.0.4515.159 fixes following issues:
  CVE-2021-30598, CVE-2021-30599, CVE-2021-30600, CVE-2021-30601,
  CVE-2021-30602, CVE-2021-30603, CVE-2021-30604
* Thu Aug 12 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 78.0.4093.147
  - CHR-8251 Update chromium on desktop-stable-92-4093
    to 92.0.4515.131
  - DNA-93036 Opera not starting after closing window.
    Processes still working.
  - DNA-94516 Add ‘Detach tab’ entry to tab menu
  - DNA-94584 [Mac] Sidebar setup not closed after press
    ‘Add extensions’ button
  - DNA-94761 Crash when trying to record “Chrome developer” trace
  - DNA-94790 Crash at opera::VideoConferenceTabDetachController::
    OnBrowserAboutToStartClosing(Browser*)
- The update to chromium 92.0.4515.131 fixes following issues:
  CVE-2021-30590, CVE-2021-30591, CVE-2021-30592, CVE-2021-30593,
  CVE-2021-30594, CVE-2021-30596, CVE-2021-30597
* Sun Aug  8 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 78.0.4093.112
  - DNA-94466 Implement sorting Pinboards in overview
  - DNA-94582 Add access to APIs for showing pinboard icon in
    sidebar
  - DNA-94603 Suspicious pinboards events
  - DNA-94625 Disable opr.pinboardPrivate.getThumbnail() for
    local files
  - DNA-94640 Promote O78 to stable
  - DNA-94661 Missing translations for some languages
- Complete Opera 78.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-78/
* Thu Jul 22 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 77.0.4054.277
  - CHR-8502 Update chromium on desktop-stable-91-4054 to
    91.0.4472.164
  - DNA-94291 Video conference popout doesnt remember its size
    after resizing
  - DNA-94399 Incorrect icon for wp.pl in address bar dropdown
  - DNA-94462 Low quality of default wallpaper on windows
- The update to chromium 91.0.4472.164 fixes following issues:
  CVE-2021-30541, CVE-2021-30560, CVE-2021-30561, CVE-2021-30562,
  CVE-2021-30563, CVE-2021-30564
* Thu Jul 15 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 77.0.4054.254
  - DNA-92344 Windows 10 Implementation
  - DNA-92486 Replace ⓧ icon with “settings” icon
  - DNA-92487 Close individual item
  - DNA-92496 Create separate entry in settings for BABE
  - DNA-93275 Implement cycles size according to design
  - DNA-93280 The system theme has only half a checkmark
  - DNA-93728 Whatsapp notification is not refreshed
  - DNA-94047 Remove pinboard WebUI integration
  - DNA-94118 Write test for ThumbnailTabHelper changes in DNA-94100
  - DNA-94120 Fix Welcome popup layout
  - DNA-94140 Crash at base::TaskRunner
    ::PostTask(base::Location const&, base::OnceCallback)
  - DNA-94205 Consider setting pinboard display URL in
    address_field_helper.cc
  - DNA-94211 Easy Files don’t show thumbnails
  - DNA-94309 Pinboards URLs don’t get lighter color treatment
  - DNA-94318 Wrong ‘Transparency’ word translation in Swedish
  - DNA-94321 AB test: google suggestions on top – bigger test
  - DNA-94341 Make pinboard popup testable on web page
  - DNA-94381 Disabling Pinboards doesn’t remove item from
    menu / sidebar
  - DNA-94392 Add u2f-devices interface to snap packages
  - DNA-94461 Enable #system-theme on all streams
* Fri Jul  9 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 77.0.4054.203
  - CHR-8475 Update chromium on desktop-stable-91-4054 to
    91.0.4472.124
  - DNA-93523 Crash at extensions::TabHelper::WebContentsDestroyed()
  - DNA-93917 Upload snap to edge while preparing repository package
  - DNA-94157 Crash at gfx::ICCProfile::operator=(gfx::ICCProfile const&)
  - DNA-94159 Crash at opera::auth::AuthAccountServiceImpl::GetAuthAccount()
  - DNA-94161 [Add tabs]Unexpected symbols instead of Workspace name
  - DNA-94241 Implement better process killing for timeout
  - DNA-94248 Allow retry on tests that timed-out
  - DNA-94251 heap-use-after-free in VideoConference
  - DNA-94315 Crash at class std::__1::basic_string ui::ResourceBundle::
    LoadLocaleResources(const class std::__1::basic_string& const, bool)
  - DNA-94357 Fix issue in scripts
* Thu Jul  1 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 77.0.4054.172
  - DNA-93078 Do not display ‘share tab’ sliding toolbar on
    detached tab
  - DNA-93358 The red underline extends beyond the Google meets
    conference tab outline
  - DNA-93404 Crash in test when destroying BABE’s webcontents
  - DNA-93637 ctrl+9 shortcut is inconsistent with other browsers
  - DNA-93661 Add opauto test to cover new shortcut from DNA-93637
  - DNA-93867 Use version from package instead of repository
  - DNA-93993 Pinboard translations from Master
  - DNA-94099 Increase new-autoupdater-logic AB test to cover
    50%% of new installations
  - DNA-94100 Thumbnail doesn’t update
  - DNA-94178 Automatic popout should not happen after manually
    closing a popout
* Thu Jun 24 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 77.0.4054.146
  - CHR-8458 Update chromium on desktop-stable-91-4054 to
    91.0.4472.114
  - DNA-92171 Create active linkdiscovery service
  - DNA-92388 Fix and unskip
    WorkspacesEmoji.testChooseEmojiAsWorkspaceIcon when possible
  - DNA-93101 Tabs are being snoozed when tab snoozing is disabled
  - DNA-93386 Update pinboard view when item changes
  - DNA-93448 Make browser ready for Developer release
  - DNA-93491 Fix failing tests after enabling #pinboard flag
  - DNA-93498 Add additional music services
  - DNA-93503 Blank popup on clicking toolbar icon with popup open
  - DNA-93561 Do not allow zoom different from 100%% in Pinboard popup
  - DNA-93637 ctrl+9 shortcut is inconsistent with other browsers
  - DNA-93644 Create route for `import open tabs` to `pinboard`
  - DNA-93664 Adapt popup to design
  - DNA-93702 Turn on flags on developer
  - DNA-93737 [Pinboard] Remove Mock API
  - DNA-93745 Unable to open the popup after opening it several times
  - DNA-93776 Popup closes and reopens when clicking the toolbar button
  - DNA-93786 DCHECK after opening popup
  - DNA-93802 Crash at views::Widget::GetNativeView() const
  - DNA-93810 Add pinboard icon to sidebar
  - DNA-93825 Add pinboard to Opera menu
  - DNA-93833 [Player] Implement seeking for new services
  - DNA-93845 Do not log output of snapcraft on console
  - DNA-93864 Create feature flag for start page sync banner
  - DNA-93865 Implement start page banner
  - DNA-93867 Use version from package instead of repository
  - DNA-93878 [Player] Crash when current player service becomes
    unavailable when user location changes
  - DNA-93953 ‘Send image to Pinboard’ has the wrong position
    in the context menu
  - DNA-93987 Disable zooming popup contents like in other popups
  - DNA-93989 Change internal URL to opera://pinboards
  - DNA-93990 Update strings to reflect new standards
  - DNA-93992 Add Pinboards to Opera settings
  - DNA-93993 Pinboard translations from Master
  - DNA-94011 Enable feature flags for Reborn 5 on stable
  - DNA-94019 Add a direct link to settings
  - DNA-94088 Internal pages provoke not saving other pages to
    the Pinboard
  - DNA-94111 [O77] Sidebar setup does not open
  - DNA-94139 Crash at
    opera::(anonymous namespace)::PinboardPopupWebView::RemovedFromWidget()
- The update to chromium 91.0.4472.114 fixes following issues:
  CVE-2021-30554, CVE-2021-30555, CVE-2021-30556, CVE-2021-30557
* Mon Jun 21 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 77.0.4054.90
  - CHR-8446 Update chromium on desktop-stable-91-4054 to
    91.0.4472.101
- The update to chromium 91.0.4472.101 fixes following issues:
  CVE-2021-30544, CVE-2021-30545, CVE-2021-30546, CVE-2021-30547,
  CVE-2021-30548, CVE-2021-30549, CVE-2021-30550, CVE-2021-30551,
  CVE-2021-30552, CVE-2021-30553
- Update to version 77.0.4054.80
  - DNA-93656 Active cards in checkout Auto-fill
  - DNA-93805 Create snap packages in buildsign
  - DNA-93823 archive_opera_snap failures on Linux
  - DNA-93844 Fix AttributeError in package_type.py
* Sat Jun 12 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 77.0.4054.64
  - DNA-93159 Implement image(preview) of each created pinboard
  - DNA-93273 ‘Send image to Pinboard’ doesn’t work correct on
    staging server
  - DNA-93277 Add/update opauto tests for the System Theme WP1
    implementation p.1
  - DNA-93286 [BigSur] YT not being reloaded when opened from link
  - DNA-93296 Opera 77 translations
  - DNA-93372 Build new edition for Axel Springer
  - DNA-93376 Write unittests for PinboardImageCollector
  - DNA-93401 [LastCard] Do not change user state if not needed
  - DNA-93409 Animation with hat and glasses is missing in
    Private mode
  - DNA-93443 API opr.pinboardPrivate.getThumbnail() returns
    old thumbnail image
  - DNA-93509 Add Opera switch for pinboard staging backend
    and use it for tests
  - DNA-93519 [Sidebar] WhatsApp ‘Log out’ doesn’t work
  - DNA-93634 Fix errors in Slovak translations
  - DNA-93724 Some webstore extensions are not verified properly
- Complete Opera 77.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-77/
* Wed Jun  2 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 76.0.4017.177
  - DNA-92597 Sound controller doesn’t work after pressing
    ‘Next’ button
  - DNA-93405 Import vmp_signer instead of starting new python
    process
  - DNA-93406 [Mac] Import plist_util instead of calling script
    in _generateAppEntitlements
  - DNA-93442 Make GX Control panel attachable by webdriver
  - DNA-93554 [AdBlock] Find a fix for blocking ‘new’ YouTube ads
  - DNA-93587 Pre-refactor solution
* Wed May 26 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 76.0.4017.154
  - CHR-8420 Update chromium on desktop-stable-90-4017 to
    90.0.4430.212
  - DNA-92411 Bookmarks breadcrumbs wrong color when pressed in
    dark mode
  - DNA-92587 Sync settings: “Use old password” button doesn’t work
  - DNA-92672 Make it possible for agent to inject scripts into
    startpage
  - DNA-92712 Add SD reload API
  - DNA-93190 The bookmark can’t be opened in Workspace 5-6
  - DNA-93247 Reopen last closed tab shortcut opens random tab on
    new window
  - DNA-93294 Binary diff for opera_browser.dll is not created on
    32-bit builds
  - DNA-93313 Add opauto test to cover DNA-93190
  - DNA-93368 Fix an error in Polish translation
  - DNA-93408 [Windows] widevine_cdm_component_installer does not
    compile on desktop-stable-90-4017
- The update to chromium 90.0.4430.212 fixes following issues:
  CVE-2021-30506, CVE-2021-30507, CVE-2021-30508, CVE-2021-30509,
  CVE-2021-30510, CVE-2021-30511, CVE-2021-30512, CVE-2021-30513,
  CVE-2021-30514, CVE-2021-30515, CVE-2021-30516, CVE-2021-30517,
  CVE-2021-30518, CVE-2021-30519, CVE-2021-30520
* Wed May 12 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 76.0.4017.123
  - DNA-91951 SkipAds click by default with Adblocker on Youtube
  - DNA-92293 [Mac] Crash at opera::BrowserWindowImpl::Cleanup()
  - DNA-92714 [Mac] Worskpace switching lags with lot of tabs
  - DNA-92847 DCHECK at tab_lifecycle_unit_source.cc:145
  - DNA-92860 [Windows] Fix issues when running buildsign script
    with Python 3
  - DNA-92879 Fix issues when running buildsign script with
    Python 3
  - DNA-92938 opera://activity/ page ignores workspaces
  - DNA-93015 [Player] Panel is too narrow
  - DNA-93044 Remove unnecessary question mark in Cashback string
    in Polish
  - DNA-93070 [Search Tabs] Selecting items with cursor keys skips
    over content matches
  - DNA-93122 Use input in builddiff.py
  - DNA-93175 Fix running repacking
* Fri May  7 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 76.0.4017.107
  - CHR-8413 Update chromium on desktop-stable-90-4017 to
    90.0.4430.93
  - DNA-90168 Display SD suggestions titles
  - DNA-92693 ‘Re-attach tab’ overlay is not resized with window
  - DNA-92926 [Mac][Cashback] “Close Tab” menu item not greyed out
    for Cashback corner
  - DNA-92934 Report crashes from opera://crashes and Tooltip to
    new Atlassian
  - DNA-92980 Enable tutorials flag on all streams
- The update to chromium 90.0.4430.93 fixes following issues:
  CVE-2021-21227, CVE-2021-21232, CVE-2021-21233, CVE-2021-21228,
  CVE-2021-21229, CVE-2021-21230, CVE-2021-21231
* Sun May  2 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 76.0.4017.94
  - released on the stable branch
- Update to version 76.0.4017.88
  - CHR-8404 Update chromium on desktop-stable-90-4017
    to 90.0.4430.85
  - DNA-92219 Add bookmark API supports to the front-end
  - DNA-92409 [MAC] ‘Present now’ options windows appear behind
    detached window
  - DNA-92615 Capture tab from the tab context menu
  - DNA-92616 Capture tab from Snapshot
  - DNA-92617 Capture tab from image context menu
  - DNA-92652 Opera 76 translations
  - DNA-92680 Make image selector on any page work like bookmarks
    popup WP2
  - DNA-92707 Crash at void
    base::ObserverList::AddObserver(class content::PrerenderHost::Observer*)
  - DNA-92710 Autoupdate on macOS 11.3 not working
  - DNA-92711 Make image selector on any page work like
    bookmarks popup WP3
  - DNA-92730 Make image selector on any page work like
    bookmarks popup WP4
  - DNA-92761 Make image selector on any page work like
    bookmarks popup WP5
  - DNA-92776 Make image selector on any page work like
    bookmarks popup WP6
  - DNA-92862 Make “View pinboards” button work
  - DNA-92906 Provide in-house translations for Cashback strings
    to Spanish
  - DNA-92908 API collides with oneclick installer
- The update to chromium 90.0.4430.85 fixes following issues:
  - CVE-2021-21222, CVE-2021-21223, CVE-2021-21224, CVE-2021-21225,
    CVE-2021-21226
- Complete Opera 76.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-76/
* Tue Apr 20 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 75.0.3969.218
  - CHR-8393 Update chromium on desktop-stable-89-3969 to
    89.0.4389.128
  - DNA-92113 Windows debug fails to compile
    opera_components/ipfs/ipfs/ipfs_url_loader_throttle.obj
  - DNA-92198 [Arm] Update signing scripts
  - DNA-92200 [Arm] Create universal packages from two buildsets
  - DNA-92338 [Search tabs] The preview isn’t updated when the tab
    from another window is closed
  - DNA-92410 [Download popup] Selected item still looks bad in
    dark mode
  - DNA-92441 Compilation error
  - DNA-92514 Allow to generate universal DMG package from existing
    universal .tar.xz
  - DNA-92608 Opera 75 crash during rapid workspace switching
  - DNA-92627 Crash at automation::Error::code()
  - DNA-92630 Crash at
    opera::PremiumExtensionPersistentPrefStorageImpl::IsPremiumExtensionFeatureEnabled()
  - DNA-92648 Amazon icon disappears from Sidebar Extensions
    section after pressing Hide Amazon button
  - DNA-92681 Add missing string in Japanese
  - DNA-92684 Fix issues with signing multiple bsids
  - DNA-92706 Update repack generation from universal packages
  - DNA-92725 Enable IPFS for all channels
- The update to chromium 89.0.4389.128 fixes following issues:
  CVE-2021-21206, CVE-2021-21220
* Wed Apr 14 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 75.0.3969.171
  - CHR-8380 Update chromium on desktop-stable-89-3969 to
    89.0.4389.114
  - DNA-91889 [LastCard] Better condition to determine if
    registration is completed
  - DNA-91987 packaging:create_opautotestlist_json fails on pip
    fetching
  - DNA-92249 Synchronization ‘enabled’ pop out has patchy
    background color
  - DNA-92332 Add DigiCertGlobalRoot to get.geo.opera.com pin list
  - DNA-92362 [Win+Lin] Opera browser can’t be closed after
    dismissing the ‘Warn on quitting Opera..” dialog
  - DNA-92410 [Download popup] Selected item still looks bad
    in dark mode
  - DNA-92412 Fix adding universal package to correct build
  - DNA-92458 Dark mini player
  - DNA-92524 Missing dependency on safe_browsing
- The update to chromium 89.0.4389.114 fixes following issues:
  CVE-2021-21194, CVE-2021-21195, CVE-2021-21196, CVE-2021-21197,
  CVE-2021-21198, CVE-2021-21199
* Wed Apr  7 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 75.0.3969.141
  - CHR-8356 Update chromium on desktop-stable-89-3969 to
    89.0.4389.90
  - DNA-91636 [Linux] Use component-updated Widevine CDM
  - DNA-91909 Follow up review issues from DNA-91863
  - DNA-92220 Fix errors in O75 translations
  - DNA-92261 Enable kFeatureNewFeedbackForSearchInTabs for all streams
  - DNA-92296 Crash when clicking buttons/links on default browser infobar
  - DNA-92339 Make #cashback flag visible
- The update to chromium 89.0.4389.90 fixes following issues:
  CVE-2021-21191, CVE-2021-21192, CVE-2021-21193
- Complete Opera 75.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-75/
* Fri Mar 19 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 74.0.3911.232
  - DNA-91953 Use `default` cursor on non active elements
  - DNA-92040 Badges on extension icons are painted bad.
  - DNA-92062 Select winning variant of popup for everybody
* Sat Mar 13 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 74.0.3911.218
  - CHR-8334 Update chromium on desktop-stable-88-3911 to
    88.0.4324.192
  - DNA-91236 ExtensionTabsTest.GetWindow crashes on Mac
  - DNA-91711 Tab discards snoozes start page
  - DNA-91902 [Mac] NetInstaller size increased
  - DNA-91930 Crash at
    opera::PersistentRecentlyClosedWindows::RemoveSession(SessionID)
* Thu Mar  4 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 74.0.3911.203
  - CHR-8324 Update chromium on desktop-stable-88-3911 to
    88.0.4324.182
  - DNA-90762 Replace “Don’t show again” with “Discard”
  - DNA-90974 Crash at
    opera::PersistentRecentlyClosedWindows::GetEntryType(SessionID)
  - DNA-91289 [Search tabs] Wrong tab stays highlighted after
    removing another tab
  - DNA-91476 Invalid memory dereference PlayerServiceBrowsertest
  - DNA-91502 Change system name on opera://about page for MacOS
  - DNA-91740 Missing title in Extensions Toolbar Menu
- The update to chromium 88.0.4324.182 fixes following issues:
  CVE-2021-21149, CVE-2021-21150, CVE-2021-21151, CVE-2021-21152,
  CVE-2021-21153, CVE-2021-21154, CVE-2021-21155, CVE-2021-21156,
  CVE-2021-21157
* Mon Feb 22 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 74.0.3911.160
  - DNA-90409 Cleanup Javascript dialogs: app modal & tab modal
  - DNA-90720 [Search Tabs] Allow discarding recently closed items
  - DNA-90802 [Windows] Debug fails on linking
  - DNA-91130 heap-use-after-free in
    CashbackBackendServiceTest.AutoUpdateSchedule
  - DNA-91152 Allow reading agent variables in trigger conditions
  - DNA-91225 [Search tabs] The webpage doesn’t move from
    “Open tabs” to “Recently closed” section
  - DNA-91243 Add Rich Hint support for the cashback badge and
    popup
  - DNA-91483 component_unittests are timing out
  - DNA-91516 Sidebar setup opens only with cashback enabled
  - DNA-91601 No text in 1st line of address bar dropdown
    suggestions
  - DNA-91603 Jumbo build problem on desktop-stable-88-3911
* Tue Feb  9 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 74.0.3911.107
  - CHR-8311 Update chromium on desktop-stable-88-3911 to
    88.0.4324.150
  - DNA-90329 Implement client_capabilities negotiation for
    Flow / Sync
  - DNA-90560 [Search Tabs] Open Tabs On Top
  - DNA-90620 Add opauto tests for tab snoozing
  - DNA-90628 Update opauto tests after design changes
  - DNA-90818 Only 3 recently closed tabs are shown in a search
    mode
  - DNA-90911 Enable search-tabs-open-tabs-on-top on developer
  - DNA-90990 Crash at opera::AddressBarView::NotifyBoundsChanged()
  - DNA-90991 Opera doesn’t show version and ‘Relaunch’ button
    despite update is ready
  - DNA-91097 Crash at extensions::BrowserSidebarPrivateGetPremium
    ExtensionsInfoFunction::Run()
  - DNA-91163 [Win] “URL navigation filters” subpage doesn’t
    react on actions
  - DNA-91196 [Flow] Device capabilities is not properly saved in
    Local State
  - DNA-91276 Sidebar setup wont open
- The update to chromium 88.0.4324.150 fixes following issues:
  - CVE-2021-21148
- Complete Opera 74.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-74/
* Thu Jan 14 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 73.0.3856.344
  - CHR-8265 Update chromium on desktop-stable-87-3856 to
    87.0.4280.141
  - DNA-90625 [Mac] Crash at opera::TabView::
    GetPaintData(opera::TabState) const
  - DNA-90735 Crash at opera::BrowserSidebarModel::GetItemVisible
    (opera::BrowserSidebarItem const*) const
  - DNA-90780 Crash at extensions::CommandService::GetExtension
    ActionCommand(std::__1::basic_string const&, extensions::
    ActionInfo::Type, extensions::CommandService::QueryType,
    extensions::Command*, bool*)
  - DNA-90821 Crash at opera::BrowserSidebarController::
    Action(opera::BrowserSidebarItem const*,
    opera::BrowserSidebarItemContentView*)
- The update to chromium 87.0.4280.141 fixes following issues:
  CVE-2021-21106, CVE-2021-21107, CVE-2021-21108, CVE-2021-21109,
  CVE-2021-21110, CVE-2021-21111, CVE-2021-21112, CVE-2021-21113,
  CVE-2020-16043, CVE-2021-21114, CVE-2020-15995, CVE-2021-21115,
  CVE-2021-21116
* Tue Jan  5 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 73.0.3856.329
  - DNA-89156 Crash at content::RenderViewHostImpl::OnFocus()
  - DNA-89731 [Mac] Bookmarks bar overlaps Babe section when
    hovering the OMenu
  - DNA-90189 Music service portal logotypes are blurred on Win
  - DNA-90336 add session data schema
  - DNA-90399 Address bar dropdown suggestions overlap each other
  - DNA-90520 Crash at absl::raw_logging_internal::RawLog(absl::
    LogSeverity, char const*, int, char const*, …)
  - DNA-90538 Crash at extensions::CommandService::
    GetExtensionActionCommand(std::__1::basic_string const&,
    extensions::ActionInfo::Type, extensions::CommandService::
    QueryType, extensions::Command*, bool*)
  - DNA-90600 Don’t report workspace visibility, when
    functionality is disabled.
  - DNA-90665 Collect music service statistics WP2
  - DNA-90773 Bad translation from english to spanish in UI
  - DNA-90789 Crash at opera::ThumbnailHelper::RunNextRequest()
* Thu Dec 17 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 73.0.3856.284
  - CHR-8225 Update chromium on desktop-stable-87-3856 to
    87.0.4280.88
  - DNA-88454 Background of snap area above visible scrolled
    viewport is not captured
  - DNA-89749 Implement client_capabilities support for Flow / Sync
  - DNA-89810 Opera no longer autoselects full url/address bar
    when clicked
  - DNA-89923 [Snap] Emojis look grayed out
  - DNA-90060 Make gesture events work with search-in-tabs feature
  - DNA-90168 Display SD suggestions titles
  - DNA-90176 Player doesn’t show music service to choose on
    Welcome page
  - DNA-90343 [Mac] Cmd+C doesn’t copy snapshot
  - DNA-90538 Crash at extensions::CommandService::
    GetExtensionActionCommand(std::__1::basic_string const&,
    extensions::ActionInfo::Type, extensions::CommandService::
    QueryType, extensions::Command*, bool*)
- The update to chromium 87.0.4280.88 fixes following issues:
  CVE-2020-16037, CVE-2020-16038, CVE-2020-16039, CVE-2020-16040,
  CVE-2020-16041, CVE-2020-16042
* Thu Dec 10 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 73.0.3856.257
  - DNA-89918 #enable-force-dark flag doesn’t work anymore
  - DNA-90061 Clicking on video’s progress bar breaks autopausing
  - DNA-90079 [BigSur] Blank pages
  - DNA-90154 Crash at extensions::CommandService::
    GetExtensionActionCommand(std::__1::basic_string const&,
    extensions::ActionInfo::Type, extensions::CommandService::
    QueryType, extensions::Command*, bool*)
- Complete Opera 73.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-73/
* Wed Nov 25 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 72.0.3815.400
  - DNA-88996 [Mac] Vertical spacing of sidebar items incorrect
  - DNA-89698 [Mac] text on bookmark bar not visible when
    application is not focused
  - DNA-89746 Add product-name switch to Opera launcher and
    installer
  - DNA-89779 Implement multi-window behavior for pinned Player
  - DNA-89924 Music continue to play after the disabling Player
    from Sidebar
  - DNA-89994 Fix progress bar shape and color
  - DNA-89995 Fix font sizes, weights and colors of text in
    control panel
  - DNA-90010 Payment Methods in Settings mention Google account
  - DNA-90022 [Mac][BigSur] Crash at -[BrowserWindowController
    window:willPositionSheet:usingRect:]
  - DNA-90025 Player stays in the autopause after reloading
    panel – part 2
  - DNA-90096 Sidebar click stat not collected for Player
  - DNA-90143 Adding a stat for Player sidebar clicks to the
    Avro schema
* Sat Nov 21 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 72.0.3815.378
  - CHR-8192 Update chromium on desktop-stable-86-3815 to
    86.0.4240.198
  - DNA-86550 XHRUint8Array test time out
  - DNA-88631 Unintended volume drop
  - DNA-88708 [Snap] Inproper area snapped
  - DNA-88726 [Mac] Overlay ‘pause’ icon when Opera auto-pauses
    the Player
  - DNA-88903 Detach video button should not be visible
  - DNA-88938 Make home page reflect service configuration
  - DNA-88943 Learn more link on home page doesnt work
  - DNA-88944 Apple Music service slow to open
  - DNA-88948 Fetch audio focus request id from MediaSession
  - DNA-88949 Detach video button missing
  - DNA-88966 No accessiblity titles for services icons in home page
  - DNA-88967 Investigate creating a single BrowserSidebarModel
    instance
  - DNA-88995 Overlay “pause” is displayed when it shouldn’t
  - DNA-89017 Error when signing out of YouTube Music
  - DNA-89054 Audio is not resumed when muting audio in tab
  - DNA-89094 DCHECK when pressing Reload button
  - DNA-89095 Manage service data through PlayerService
  - DNA-89100 [Player] Crash – many scenarios
  - DNA-89187 Reload button doesn’t work properly
  - DNA-89189 Update icons and buttons
  - DNA-89217 Enable #player-service on developer stream
  - DNA-89220 SidebarCarouselTests.* failing
  - DNA-89230 Crash at v8::Context::Enter()
  - DNA-89244 Define default widths per service
  - DNA-89245 Improve Spotify logo layout in home page buttons
  - DNA-89248 Crash at opera::WebPageBrowserSidebarItemContentViewViews
    ::UpdatePlayerService()
  - DNA-89278 [Sidebar] No notification for downloads and workspaces
  - DNA-89285 [Engine] Unable to launch skype with Opera
  - DNA-89292 Do not block page loads waiting for sitecheck data
  - DNA-89316 Should be able to navigate directly to playerServices
    section in settings
  - DNA-89339 Make popup appear with tooltip-like behavior
  - DNA-89340 Implement control panel looks in light and dark mode
  - DNA-89341 Make the control panel buttons work
  - DNA-89342 Add support for the DNA to the rollout system
  - DNA-89344 Show Music Service icon in the control panel
  - DNA-89360 Make ‘Settings’ menu entry go to settings
  - DNA-89366 Make opera://feedback/babe attachable by the webdriver
  - DNA-89419 Crash at base::Value::GetAsDictionary
    (base::DictionaryValue const**) const
  - DNA-89469 Autopause does not work
  - DNA-89477 Do not wait with starting the player if the
    interrupting session is short
  - DNA-89480 Crash when hovering player panel
  - DNA-89484 Crash at base::internal::CheckedObserverAdapter
    ::IsMarkedForRemoval()
  - DNA-89489 Put control panel behind feature flag
  - DNA-89514 Implement feedback button for Player
  - DNA-89516 Do not auto-pause the Player when there is no sound
  - DNA-89553 Make the control panel show current song
  - DNA-89557 No accessibility title for rating and close buttons
    inside feedback dialog
  - DNA-89561 Make the control panel show artwork that represents
    current track
  - DNA-89575 Handle longer track and artist names
  - DNA-89577 Make progress bar work correctly
  - DNA-89630 Controler pop-up is too high (and service logo too)
  - DNA-89634 Panel width is reset when it shouldn’t
  - DNA-89654 Request higher resolution images for HiDPI
  - DNA-89655 Enable #player-service-control-panel on Developer stream
  - DNA-89671 No accessiblity titles for control panel elements
  - DNA-89672 String change “A world of music…”
  - DNA-89679 Player — don’t show control panel when Player in sidebar
    is opened
  - DNA-89722 Album cover arts are not visible
  - DNA-89766 Address bar does not respond to actions
  - DNA-89776 Control panel does not disappear after hovering elsewhere
  - DNA-89778 Implement multi-window behavior when no Player is pinned
  - DNA-89795 Player is enable after Opera restart
    (when in Settings was turned off)
  - DNA-89803 Artwork is cropped to the right
  - DNA-89812 Sidebar panel should hide when toggle between windows
  - DNA-89820 Incorrect music services for Philippines
  - DNA-89846 Do not show the control panel if there is nothing to
    show
  - DNA-89878 Clarify notification dot for messengers
  - DNA-89901 [Mac][Player] Zombie crash at exit
  - DNA-89952 Crash at opera::BrowserSidebarPlayerItemContentViewViews
    ::LoadPlayerServiceURL()
  - DNA-89964 Player stays in the autopause after reloading panel
  - DNA-89971 Multi window behaviour is not respected anymore
  - DNA-89976 Disallow docking for Player
  - DNA-89986 Enable #player-service and
    [#]player-service-control-panel on all streams
  - DNA-90006 Change services order in RU/UA/BY
- The update to chromium 86.0.4240.198 fixes following issues:
  CVE-2020-16013, CVE-2020-16017
* Tue Nov 10 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 72.0.3815.320
  - CHR-8177 Update chromium on desktop-stable-86-3815 to
    86.0.4240.183
  - DNA-89748 ‘Manage Extensions’ dialog is displayed with
    preloaded extensions
  - DNA-89766 Address bar does not respond to actions
- The update to chromium 86.0.4240.183 fixes following issues:
  CVE-2020-16004, CVE-2020-16005, CVE-2020-16006, CVE-2020-16007,
  CVE-2020-16008, CVE-2020-16009, CVE-2020-16011
* Fri Nov  6 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 72.0.3815.200
  - DNA-87150 Speed Dial tile can’t be dragged to proper place
  - DNA-89632 Improve hovering over icons
  - DNA-89647 [Light mode] Wrong URL color in ‘Add Site’ section
  - DNA-89791 Typo in Spanish
- The update to chromium 86.0.4240.111 fixes following issues:
  CVE-2020-16000, CVE-2020-16001, CVE-2020-16002, CVE-2020-15999,
  CVE-2020-16003
- Complete Opera 72.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-72/
* Wed Oct 14 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 71.0.3770.271
  - DNA-88353 Crash at opera::TabCyclerView::HighlightContents
    (content::WebContents*, bool)
  - DNA-89177 Device update request should only be called when
    FCM token has changed
  - DNA-89186 Handle device expired case in all server calls
  - DNA-89202 Pages are rendered in dark mode when force
    dark mode prefs were synced from Opera GX
  - DNA-89247 [Mac] Fullscreen video broken if sidebar is hidden
  - DNA-89298 Some elements of VPN popup are misaligned to design
  - DNA-89305 Crash after closing Downloads pop-up
* Wed Oct  7 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 71.0.3770.228
  - DNA-87466 Hide extensions icon is black in dark theme
  - DNA-88580 Implement search_in_tabs telemetry benchmark
  - DNA-88591 Allow to scroll down the Keyboards Shortcuts section
    with URL
  - DNA-88693 Random crash in SmartFilesBrowserTest
  - DNA-88793 change VPN disclaimer modal layout
  - DNA-88799 Only active workspaces and active messengers should
    be listed in keyboard shortcuts settings
  - DNA-88838 add automatic VPN connection preference setting
  - DNA-88870 Align VPN popup to new design
  - DNA-88900 Turn off Tutorials in Opera GX – implementation
  - DNA-88931 Add info about channel and product (OPR, OPRGX) to
    rollout requests
  - DNA-88940 Allow continue-shopping|booking-host-override switch
    to handle host and path
  - DNA-88946 Auto-connect VPN after browser startup only for
    existing VPN users
  - DNA-89009 Change URL for search-suggestions
  - DNA-89021 Make RH test driver pack to a separate archive
  - DNA-89150 Unhardcode ‘From’ and ‘To’ strings in Advanced
    History Search
  - DNA-89175 Desktop without a flow paring should not initialize
    in browser startup
* Wed Sep 30 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 71.0.3770.198
  - CHR-8106 Update chromium on desktop-stable-85-3770 to
    85.0.4183.121
  - DNA-85648 Reconnecting Flow with iOS is unstable
  - DNA-87130 Spinner is stretched instead of clipped
  - DNA-87989 In Find in Page, “No matches” doesn’t go away after
    deleting all text
  - DNA-88098 Data URLs entries should not open new tab after
    click on new history page
  - DNA-88267 Extra semicolon in Russian BABE translation
  - DNA-88312 [Win] Downloads file drag and drop doesn’t work in
    Opera
  - DNA-88363 Add premium extension functionality
  - DNA-88580 Implement search_in_tabs telemetry benchmark
  - DNA-88611 Black font on a dark background in sync login dialog
  - DNA-88626 Disable #easy-files on desktop-stable-85-xxxx
  - DNA-88701 String “Type a shortcut” is hardcoded
  - DNA-88755 Crash at extensions::WebstoreOneClickInstallerUIImpl::
    RemoveAllInfobarsExcept(opera::ExtensionInstallInfoBarDelegate*)
  - DNA-88797 Change ‘Register’ to ‘Tab’ in German
  - DNA-88851 [History][Resized window] Button and date input
    look bad
  - DNA-88958 Crash at net::`anonymous namespace”::Escape
- The update to chromium 85.0.4183.121 fixes following issues:
  - CVE-2020-15960, CVE-2020-15961, CVE-2020-15962, CVE-2020-15963,
    CVE-2020-15965, CVE-2020-15966, CVE-2020-15964
* Wed Sep 16 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 71.0.3770.148
  - CHR-8091 Update chromium on desktop-stable-85-3770 to
    85.0.4183.102
  - DNA-87785 [Mac] “Alitools” text in extension toolbar overlaps
    Install button
  - DNA-87935 Make SSD smaller by 25%%
  - DNA-87963 Hidden Avira extension in avira_2 edition
  - DNA-88015 [MyFlow] Desktop doesn’t show itself in devices list
  - DNA-88469 Add context menu options to configure shortcuts
  - DNA-88496 Define a/b test in ab_tests.json
  - DNA-88537 Don’t filter out hashes from feature reference groups
    coming from rollout
  - DNA-88580 Implement search_in_tabs telemetry benchmark
  - DNA-88604 [History panel] Search bar covers the
    “Clear browsing data” button
  - DNA-88619 String ‘Download complete’ is cut on download popup
  - DNA-88645 Remove option should not be available for last
    workspace
  - DNA-88718 [History panel] fix delete button overflow issue
- The update to chromium 85.0.4183.102 fixes following issues:
  - CVE-2020-6573, CVE-2020-6574, CVE-2020-6575, CVE-2020-6576,
    CVE-2020-15959
- Complete Opera 71.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-71/
* Tue Sep  1 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 70.0.3728.144
  - CHR-8057 Update chromium on desktop-stable-84-3728 to
    84.0.4147.135
  - DNA-88027 [Mac] Downloads icon disappears when downloads popup
    is shown
  - DNA-88204 Crash at opera::DownloadItemView::OnMousePressed
    (ui::MouseEvent const&)
- The update to chromium 84.0.4147.135 fixes following issues:
  - CVE-2020-6556
* Tue Aug 25 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 70.0.3728.133
  - CHR-8053 Update chromium on desktop-stable-84-3728 to
    84.0.4147.125
  - DNA-87289 Crash at views::NativeWidgetMacNSWindowHost::
    OnNativeViewHostDetach(views::View const*)
  - DNA-87831 [Linux] Sidebar panel cannot be pinned
  - DNA-88057 [Win] Black rectangle flickers at the bottom of the
    page on startup
  - DNA-88157 Sidebar Messenger too low in FullScreen mode
  - DNA-88238 [macOS 10.15] Toolbar buttons not visible on inactive
    tab
- The update to chromium 84.0.4147.125 fixes following issues:
  - CVE-2020-6542, CVE-2020-6543, CVE-2020-6544, CVE-2020-6545,
    CVE-2020-6546, CVE-2020-6547, CVE-2020-6548, CVE-2020-6549,
    CVE-2020-6550, CVE-2020-6551, CVE-2020-6552, CVE-2020-6553,
    CVE-2020-6554, CVE-2020-6555
* Tue Aug 18 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 70.0.3728.119
  - DNA-88215 Introduce easy-setup-hint-ref feature flag
- Update to version 70.0.3728.106
  - DNA-88014 [Mac] Toolbar in fullscreen disabled after using
    fullscreen from videoplayer
* Wed Aug  5 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 70.0.3728.95
  - CHR-8026 Update chromium on desktop-stable-84-3728 to
    84.0.4147.105
  - DNA-86340 Wrong link to the help page
  - DNA-87394 [Big Sur] Some popovers have incorrectly themed arrow
  - DNA-87647 [Win] The [+] button flickers after creating a new tab
  - DNA-87794 Crash at aura::Window::SetVisible(bool)
  - DNA-87796 Search in tabs should closed on second click
  - DNA-87863 Parameter placing issue in all languages
- The update to chromium 84.0.4147.105 fixes following issues:
  - CVE-2020-6537, CVE-2020-6538, CVE-2020-6532, CVE-2020-6539,
    CVE-2020-6540, CVE-2020-6541
* Thu Jul 30 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 70.0.3728.71
  - DNA-86267 Make `Recently closed tabs` appearance consistent
    with `Search for open tabs`.
  - DNA-86988 Opera 70 translations
  - DNA-87530 Zen news leads not loading
  - DNA-87636 Fix displaying folder icon for closed windows in
    recently closed list
  - DNA-87682 Replace Extensions icon in toolbar with icon from
    sidebar
  - DNA-87756 Extend chrome.sessions.getRecentlyClosed with
    information about last active tab in window.
  - DNA-87778 Crash at opera::InstantSearchViewViews::
    ~InstantSearchViewViews()
  - DNA-87815 Change affiliate links for AliExpress Search
- Update to version 70.0.3728.59
  - CHR-8010 Update chromium on desktop-stable-84-3728 to
    84.0.4147.89
  - DNA-87019 The video image does not respond to the pressing
    after closed the “Quit Opera?” dialog
  - DNA-87342 Fix right padding in settings > weather section
  - DNA-87427 Remove unneded information from the requests’
    diagnostics
  - DNA-87560 Crash at views::Widget::GetNativeView()
  - DNA-87561 Crash at CRYPTO_BUFFER_len
  - DNA-87599 Bypass VPN for default search engines doesn’t work
  - DNA-87611 Unittests fails on declarativeNetRequest and
    declarativeNetRequestFeedback permissions
  - DNA-87612 [Mac] Misaligned icon in addressbar
  - DNA-87619 [Win/Lin] Misaligned icon in addressbar
  - DNA-87716 [macOS/Windows] Crash when Search in tabs is open
    and Opera is minimised
  - DNA-87749 Crash at opera::InstantSearchSuggestionLineView::
    SetIsHighlighted(bool)
- The update to chromium 84.0.4147.89 fixes following issues:
  - CVE-2020-6510, CVE-2020-6511, CVE-2020-6512, CVE-2020-6513,
    CVE-2020-6514, CVE-2020-6515, CVE-2020-6516, CVE-2020-6517,
    CVE-2020-6518, CVE-2020-6519, CVE-2020-6520, CVE-2020-6521,
    CVE-2020-6522, CVE-2020-6523, CVE-2020-6524, CVE-2020-6525,
    CVE-2020-6526, CVE-2020-6527, CVE-2020-6528, CVE-2020-6529,
    CVE-2020-6530, CVE-2020-6531, CVE-2020-6533, CVE-2020-6534,
    CVE-2020-6535, CVE-2020-6536
- Complete Opera 70.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-70/
* Wed Jul 15 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 69.0.3686.77
  - DNA-84207 New Yubikey enrollment is not working
  - DNA-87185 Lost translation
  - DNA-87382 Integrate scrolling to top of the feed with the
    existing scroll position restoration
  - DNA-87535 Sort out news on startpage state
  - DNA-87588 Merge “Prevent pointer from being sent in the clear
    over SCTP” to desktop-stable-83-3686
* Wed Jul  8 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 69.0.3686.57
  - DNA-86682 Title case in Russian translation
  - DNA-86807 Title case in O69 BR Portuguese translation
  - DNA-87104 Right click context menu becomes scrollable sometimes
  - DNA-87376 Search in tabs opens significantly slower in O69
  - DNA-87505 [Welcome Pages][Stats] Session stats for
    Welcome and Upgrade pages
  - DNA-87535 Sort out news on startpage state
* Tue Jul  7 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 69.0.3686.49
  - CHR-7971 Update chromium on desktop-stable-83-3686 to
    83.0.4103.116 (CVE-2020-6509)
  - DNA-79195 Wrong date on history
  - DNA-86090 Crash at views::View::ReorderChildView(views::View*, int)
  - DNA-86122 [Mac] Some popovers have incorrectly themed arrow
  - DNA-86833 Add hint to tell users that tab content is now searched
  - DNA-86906 [Search in tabs] No matching results in your open
    tabs label not displayed for some strings not found.
  - DNA-86983 Allow to search from the tile
  - DNA-87029 Search in tabs dropdown should disappear when
    resizing window
  - DNA-87051 No autocompletion in the address bar for Speed Dials
  - DNA-87091 Do not vertically center search-in-tabs dialog
  - DNA-87113 Crash at content::NavigationRequest::GetRenderFrameHost()
  - DNA-87114 Double scrollbar in bookmarks popup
  - DNA-87117 Hide “Provide additional details” button when crash
    is discarded by Socorro
  - DNA-87122 Hide provide more information button from infobar
    when crash is discarded
  - DNA-87153 The icons cover the inscription on the BABE
    picture title
  - DNA-87203 The scroll view changes visible area unexpectedly
  - DNA-87243 Provide missing translations
  - DNA-87245 Extend schema and report search events
  - DNA-87261 Allow to use search and modal at the same time
  - DNA-87273 Switch to dedicated subdomain
- Complete Opera 69.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-69/
* Fri Jun 19 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 68.0.3618.173
  - DNA-85512 SNAP CTRL+C not working as expected on some pages
  - DNA-85580 Crash at ThumbnailTabHelper::StartVideoCapture()
  - DNA-86357 Crash at remote_cocoa::NativeWidgetNSWindowBridge::
    SetVisibilityState(remote_cocoa::mojom::WindowVisibilityState)
  - DNA-87146 Support new design for overlays
* Thu Jun 11 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to versiopn 68.0.3618.165
  - DNA-85650 Crash at TabStripModel::GetIndexOfWebContents
    (content::WebContents const*)
  - DNA-85911 No information of downloaded file, which isn’t
    existed on PC
  - DNA-86273 Disabled AdBlock blocks resources inside IFrame
  - DNA-86281 [Mac] Wrong zoom button color
  - DNA-86574 Invalid thread used for opera::content_filter::
    renderer::GetTopFrameURL()
  - DNA-86654 Dropdown icon do nothing if clicking on it
  - DNA-86705 [WIN] Media permissions dialog not shown for
    sidebar messengers
* Thu May 14 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 68.0.3618.104
  - CHR-7909 Update chromium on desktop-stable-81-3618 to 81.0.4044.138
  - CVE-2020-6831, CVE-2020-6464
  - DNA-85609 [Mac] Tabs shrinking & disappearing
  - DNA-85629 Crash at opera::DownloadButtonPanel::ShouldShowCancelButton()
  - DNA-85669 Add mocking of AddressDropdownModel in AddressBarControllerTest
  - DNA-85678 Wrong badge icon on pages with mixed content on desktop-stable-81-3618
  - DNA-85820 Flags are blue in default [D] state after restart
  - DNA-85822 Full screen snap on pkobp.pl
  - DNA-86077 Problem to upload .JPG file as an wallpaper
  - DNA-86165 Downloads list doesn’t returns to its original state after clearing search filter
  - DNA-86236 [Mac] Plus button click area too small
  - DNA-86241 X tab button is not visible
  - DNA-86217 Fix performance issue with Background Worker
* Sat May  2 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 68.0.3618.63
  - CHR-7889 Update chromium on desktop-stable-81-3618 to
    81.0.4044.122
  - CHR-7896 Update chromium on desktop-stable-81-3618 to
    81.0.4044.129
  - DNA-85287 Set standard spacing for Yandex prompt
  - DNA-85416 [Mac] Animation of tab insert is glitchy on slow
    machines
  - DNA-85568 Verify API for triggering “unread” mode with
    Instagram.
  - DNA-86027 Present Now not working in google meet after
    canceling it once
  - DNA-86028 Add a back and forward button in the Instagram panel
  - DNA-86029 Investigate and implement re-freshing of the
    instagram panel content
- Update chromium to 81.0.4044.122 fixes CVE-2020-6458,
  CVE-2020-6459, CVE-2020-6460
- Update chromium to 81.0.4044.129 fixes CVE-2020-6461,
  CVE-2020-6462
* Wed Apr 29 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 68.0.3618.56
  - DNA-85256 [Win] Cookies section on site pages is white in
    dark mode
  - DNA-85474 [Mac] Dragging tabs to the left with hidden sidebar
    is broken
  - DNA-85771 DNS-over-HTTPS example in settings is wrong
  - DNA-85976 Change page display time when navigating from
    opera:startpage
  - CHR-7878 Update chromium on desktop-stable-81-3618 to
    81.0.4044.113 (CVE-2020-6457)
  - DNA-78158 PATCH-1272 should be removed
  - DNA-84721 Weather widget is overlapped when ‘Use bigger tiles’
  - DNA-85246 Implement 0-state dialog and onboarding
  - DNA-85354 O-menu is misplaced when opened with maximized opera
  - DNA-85405 Add link to Privacy Policy on the 0-state dialog
  - DNA-85409 Ask for geolocation EULA once
  - DNA-85426 Crash at opera::DownloadActionButton::Update()
  - DNA-85454 Add id’s to elements for testing
  - DNA-85493 Add “Show Weather” toggle to “Start Page” section
    in Easy Setup
  - DNA-85501 Set timestamps in geolocation exception record
  - DNA-85514 Add fallback when geolocation fails
  - DNA-85713 Report consent for geolocation on start page
  - DNA-85753 Fetch news configuration from new endpoint
  - DNA-85798 Incorrect padding in Search in Tabs window
  - DNA-85801 Disable notification on instagram panel
  - DNA-85809 Update instagram icon in the Sidebar Setup
  - DNA-85854 Change Instagram panel size, to fit desktop
    version
- Complete Opera 68.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-68/
* Thu Apr  9 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 67.0.3575.137
  - CHR-7852 Update chromium on desktop-stable-80-3575
    to 80.0.3987.163
  - DNA-82540 Crash at remote_cocoa::NativeWidgetNSWindowBridge::
    SetVisibilityState(remote_cocoa::mojom::WindowVisibilityState)
  - DNA-84951 New PiP is completely black for some 2 GPU setups
  - DNA-85284 Chrome “Open link in same tab, pop-up as tab [Free]”
    extension is no longer working in Opera
  - DNA-85415 [Mac] Inspect Popup not working
  - DNA-85530 Create API for displaying and triggering “unread”
    mode for messengers from in-app
  - DNA-85537 Let addons.opera.com interact with sidebar messengers
* Sat Mar 28 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 67.0.3575.115
  - CHR-7833 Update chromium on desktop-stable-80-3575
    to 80.0.3987.149
  - DNA-74423 [Mac] Search/Copy popup stuck on top left of screen
  - DNA-82975 Crash at blink::DocumentLifecycle::EnsureStateAtMost
    (blink::DocumentLifecycle::LifecycleState)
  - DNA-83834 Crash at base::MessagePumpNSApplication:: DoRun
    (base::MessagePump::Delegate*)
  - DNA-84632 macOS 10.15.2 fail on creating testlist.json
  - DNA-84713 Switching through tabs broken when using workspaces
* Thu Mar 19 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 67.0.3575.97
  - DNA-84063 Open URL in new tab with ‘Go to web address’ in
    search/copy popup and right mouse click context menu
  - DNA-84780 Search in Search and Copy popup opens tab in wrong
    position from popup window
  - DNA-84786 Crash at Browser::PasteAndGo(std::__1::basic_string
    const&, WindowOpenDisposition)
  - DNA-84815 Crash at TabStripModel::GetIndexOfWebContents
    (content::WebContents const*)
  - DNA-84937 [Mac] Workspace switching is slow with a lot of
    tabs opened
  - DNA-85159 Sidebar-setup not refreshed correctly after
    signing out from sync
* Fri Mar 13 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 67.0.3575.79
  - CHR-7804 Update chromium on desktop-stable-80-3575 to
    80.0.3987.132
  - DNA-83766 Opera Ad Blocker extension state is not updated when
    changing it
  - DNA-83966 Enable kFeatureSuggestionScoringImproved on all the
    streams
  - DNA-84159 Settings – list of workspaces in the settings isn’t
    updated after reordering
  - DNA-84396 Inline autocomplete not working when SD becomes
    the top-scored suggestion
  - DNA-84711 Wrong autocomplete address for https sites
  - DNA-84741 No amazon partner extension displayed
  - DNA-84743 Crash at ExtensionsToolbarContainer::UndoPopOut()
  - DNA-84776 Bookmarks not fully displayed in Bookmarks Panel
  - DNA-84817 Crash at Browser::IsSearchAndCopyPopupEnabled()
  - DNA-84836 Broken video playback in some cases
  - DNA-84837 Audio decoder broken although available on Windows 7
  - DNA-84860 [Mac] Address field not highlighted on hover
  - DNA-84889 [desktop-stable-80-3575] There’re no basic settings
  - DNA-84910 Fix output type selection of SW H.264 decoder
  - DNA-84938 Prepare stable build with Yx 05 edition
  - DNA-84969 Address bar dropdown launches HTTP GETs for every
    autocomplete
* Thu Mar  5 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 67.0.3575.53
  - CHR-7792 Update chromium on desktop-stable-80-3575
    to 80.0.3987.122
  - DNA-84024 ‘Save all Tabs in Speed Dial Folder’ doesn’t work
    on main context menu
  - DNA-84056 Submenus are not scrollable
  - DNA-84061 Expanded bookmark menu overlaps the whole toolbar
  - DNA-84277 Whole text should be visible
  - DNA-84412 Dragging tab to different place activates another tab
  - DNA-84492 Disable any notifications for “default browser”
    from sweetlabs builds
  - DNA-84691 Crash when trying to open sidebar context menu
* Fri Feb 28 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 67.0.3575.31
  - DNA-84077 Hide seek and timer controls in video pop-out
    for YouTube live streams
  - DNA-84639 Promote O67 to stable
- Complete Opera 67.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-67/
* Tue Feb 18 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 66.0.3515.103
  - DNA-83528 UnpackTest.CanUnpackTarXzFile test fails on OSX 10.15+
  - DNA-83568 Add test driver perftests
  - DNA-84335 [Linux] Widevine is not working due to changed
    path of libwidevinecdm.so
  - DNA-84439 Opera extensions update requests are sent to chrome
    instead of opera servers
* Wed Feb  5 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 66.0.3515.72
  - DNA-79691 Unable to play video on Netflix right after Opera
    installation
  - DNA-82102 Wrong cursor and X color of the search fields on
    Bookmark/History sidebar panels
  - DNA-82722 Google Translator blocks PDF viewer
  - DNA-83407 Crash at static void
    `anonymous namespace”::PureCall()
  - DNA-83530 Bad colors in Personal news when dark theme turned on
  - DNA-83531 Dragging speed dial root folders in bookmarks
    sidebar makes duplicates
  - DNA-83542 Fix background tabs loading issues
  - DNA-83806 Crash at opera::RichHintDisplayHandlerViews::
    OnWidgetDestroying(views::Widget*)
  - DNA-83882 Crash at base::Value::Clone()
  - DNA-84007 Accessibility elements visible on pages after
    first navigation on Mac
* Fri Jan 24 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 66.0.3515.44
  - CHR-7734 Update chromium on desktop-stable-79-3515
    to 79.0.3945.130
  - DNA-82635 [Mac] Fix crash when opening power save popup twice
  - DNA-83587 Fix Crash at
    opera::ThumbnailHelper::ThumbnailRequest::PopNextFrameToPaint()
  - DNA-83698 Unregister extensions keybindings when sidebar
    is hidden
  - DNA-83757 Stop making thumbnail after history onboarding
    will show
* Sun Jan 19 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 66.0.3515.36
  - CHR-7717 Update chromium on desktop-stable-79-3515
    to 79.0.3945.117
  - DNA-81359 Translate “Speed Dials” folder in bookmarks panel
  - DNA-82627 Unify & streamline tooltip color processing
    across Opera.
  - DNA-82800 Enable
    kFeatureTurnOnFeaturesDownloadedByInstallerOnUpdates on
    all streams
  - DNA-83190 Record SwitchToFullSite events on icon clicks.
  - DNA-83496 Check if history-panel is enabled before showing
    onboarding.
  - DNA-83545 Fix a crash in adblocker rule update
  - DNA-83583 [Mac] Bookmark popup too bright in dark mode
  - DNA-83608 Set “plat” metadata in crash reports from Linux.
* Mon Jan 13 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to version 66.0.3515.27
  - DNA-82683 Bookmarks menu is not readable in dark mode
    after hovering
  - DNA-83139 [macOS] screenshot is resized
  - DNA-83204 [Mac] Anchor onboarding widget to history
    icon on sidebar
  - DNA-83205 [Mac] Popup looks bad with mode change
  - DNA-83351 Enable feature on stable/beta
  - DNA-83366 [Mac] Onboarding popup doesn’t follow the browser
    window
  - DNA-83402 Promote O66 to stable
- Complete Opera 66.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-66/
* Tue Dec 10 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to version 65.0.3467.69
  - DNA-82647 Tab icons mixed after Tab closing
  - DNA-82919 Update wrapper to skip package types when
    creating repo
  - DNA-82967 [Mac] Opera crashes on dragging the SSL icon
    on the URL Bar
* Wed Dec  4 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to version 65.0.3467.62
  - CHR-7658 Update chromium on desktop-stable-78-3467
    to 78.0.3904.108
  - DNA-81387 Remove support for old bundle structure
    in signing scripts
  - DNA-81675 Update widevine signature localisation in
    signed packages
  - DNA-81884 [Advanced content blocking] Ads are blocked
    for whitelisted page in Incognito
  - DNA-82230 [Mac] URL is not correctly aligned when
    the Geolocation is ON
  - DNA-82368 Generating diffs for unsinged packages doesn’t work
  - DNA-82414 Wrong number of trackers displayed just after
    deactivating adblocker
  - DNA-82470 [Linux] Snap package doesn’t recognise GNOME 3.24
    platform snap connection
  - DNA-82473 https://www.nba.com/standings not working with
    AdBlocker enabled
  - DNA-82484 Update content blocking icon
  - DNA-82485 [Mac 10.15] Opera installer error at the end of
    installation process
  - DNA-82508 [Adblocker] Predefault lists can not be unchecked
  - DNA-82557 Address bar dropdown launches HTTP GETs for
    every autocomplete
  - DNA-82596 Do not block first-party ‘trackers’
  - DNA-82616 Settings – Tracker Blocker – Add “Learn more” link
  - DNA-82626 [Win] High CPU usage due to media indicator animation
  - DNA-82647 Tab icons mixed after Tab closing
  - DNA-82742 Pages won’t load after closing private mode
  - DNA-82768 Mark also the reference group in “exp” header
    for DNA-81658
  - DNA-82840 Disable favicon fetching for typed URLs
- Complete Opera 65.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-65/
* Thu Nov  7 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to version 64.0.3417.92
  - DNA-81358 Wrong key color on extension popup in dark mode
  - DNA-82208 Cherry-pick CVE-2019-13721 and CVE-2019-13720
* Thu Oct 31 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to version 64.0.3417.83
  - DNA-79676 Use FFmpegDemuxer to demux ADTS
  - DNA-81010 Spinner takes a lot of cpu
  - DNA-81385 Keys on some popups in dark mode can’t be hovered
  - DNA-81494 [Mac] Snap onboarding doesn’t appear while
    the icon still flashes
  - DNA-82003 Restore legacy path for AudioFileReader
  - DNA-82019 Enable #ffmpeg-demuxer-everywhere by default
    in developer
  - DNA-82028 Enable #ffmpeg-demuxer-everywhere by default
    in stable on macOS
* Thu Oct 24 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to version 64.0.3417.73
  - CHR-7598 Update chromium on desktop-stable-77-3417
    to 77.0.3865.120
  - DNA-80049 The upper border of “Add to bookmarks bar” popup
    is cut off in white mode
  - DNA-80395 Menu popup borders in Settings are invisible
    in Dark mode
  - DNA-81263 Change the continue section buttons visibility
    as in description
  - DNA-81304 Crash at chrome::NewTab(Browser*)
  - DNA-81650 Easy Setup Style looks weird
  - DNA-81708 Missing dependency on //chrome/common:buildflags
  - DNA-81732 [Mac][Catalina] Cannot maximize a window
    after it’s been minimized
  - DNA-81737 Renderer crash on https://codesandbox.io/s/vanilla-ts
  - DNA-81753 Pinned tab only remembered after next restart
  - DNA-81769 Investigate reports about slow speed dial loading
    in O64 blog comments
  - DNA-81859 [Mac 10.15] Crash whenever navigating to any page
  - DNA-81893 Get Personalised news on SpeedDials broken layout
* Thu Oct 17 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to version 64.0.3417.61
  - DNA-80760 Sidebar Messenger icon update
  - DNA-81165 Remove sharing service
  - DNA-81211 [Advanced content blocking] Can not turn off
    ad blocking in private mode
  - DNA-81323 content_filter::RendererConfigProvider destroyed
    on wrong sequence
  - DNA-81487 [VPN disclaimer][da, ta] Text should be multiline
  - DNA-81545 opr-session entry for Google ads not working
  - DNA-81580 Speed dials’ colours change after Opera update
  - DNA-81597 [Adblocker] Google Ads link hides if clicking
  - DNA-81639 Widevine verification status is PLATFORM_TAMPERED
  - DNA-81237 [Advanced content blocking] noCoinis
    not enabled by default
  - DNA-81375 Adblocking_AddToWhitelist_Popup and
    Adblocking_RemoveFromWhitelist_Popup metric not recorded
    in stats
  - DNA-81413 Error in console when Start Page connects to My Flow
  - DNA-81435 Adjust VPN disclaimer to longer strings [de]
- Removed Recommends: flash-player-ppapi
* Thu Oct 10 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to version 64.0.3417.47
  - DNA-80531 [Reborn3] Unify Switches
  - DNA-80738 “How to protect my privacy” link
  - DNA-81162 Enable #advanced-content-blocking
    on developer stream
  - DNA-81202 Privacy Protection popup doesn’t resize after
    enabling blockers
  - DNA-81230 [Mac] Drop support for 10.10
  - DNA-81280 Adjust button width to the shorter string
  - DNA-81295 Opera 64 translations
  - DNA-81346 Enable #advanced-content-blocking on all streams
  - DNA-81434 Turn on #new-vpn-flow in all streams
  - DNA-81436 Import translations from Chromium to O64
  - DNA-81460 Promote O64 to stable
  - DNA-81461 Snap onboarding is cut
  - DNA-81467 Integrate missing
    translations (Chinese, MS and TL) to O64/65
  - DNA-81489 Start page goes into infinite loop
- Complete Opera 64.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-64/
* Sat Sep 21 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to version 63.0.3368.94
  - CHR-7516 Update chromium on master to 78.0.3887.7
  - DNA-80966 [Linux] Integrate a new key into our packages
* Fri Sep 13 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to version 63.0.3368.88
  - DNA-79103 Saving link to bookmarks saves it to Other
    bookmarks folder
  - DNA-79455 Crash at views::MenuController::
    FindNextSelectableMenuItem(views::MenuItemView*, int, views::
    MenuController::SelectionIncrementDirectionType, bool)
  - DNA-79579 Continuous packages using
    new_mac_bundle_structure do not run
  - DNA-79611 Update opauto_paths.py:GetResourcesDir
  - DNA-79621 Add support for new bundle structure to old
    autoupdate clients
  - DNA-79906 Fix package build
  - DNA-80131 Sign Opera Helper(GPU).app
  - DNA-80191 Fix
    opera_components/tracking_data/tracking_data_paths.cc
  - DNA-80638 Cherry-pick fix for CreditCardTest.
    UpdateFromImportedCard_ExpiredVerifiedCardUpdatedWithSameName
  - DNA-80801 Very slow tab deletion process
* Mon Sep  2 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to version 63.0.3368.66
  - CHR-7525 Update chromium on desktop-stable-76-3368
    to 76.0.3809.132
  - DNA-74031 Download indicator doesn’t match progress
  - DNA-77042 Something went wrong message in crypto wallet
    in private window
  - DNA-79137 Crash at opera::installer::OptionsScreen::
    OnLanguageChanged()
  - DNA-79683 Installer crashes when showing progress
  - DNA-79757 Line divider under address bar disappears after
    opening and closing Bookmarks Bar
  - DNA-80012 Zoom popup appears each time clicking ‘heart’ icon
  - DNA-80110 Bug when changing the install path in installer
  - DNA-80417 [assistant] Crash at
    opera::avro::event_driven::StatSenderImpl::NetworkThread::
    SetTrafficAllowed(bool)
  - DNA-80422 Continue shopping section is too close to Speed Dial
    tiles when tiles are big
  - DNA-80463 Add shadow to shopping tiles
  - DNA-78143 Load async resources before rendering the page
  - DNA-79102 Make AU to be always server IPC endpoint when
    new AU logic is enabled
  - DNA-80193 Magnifying glass icon doesn’t match the search box
    boundaries in settings and extensions
  - DNA-80416 Crash at opera::assistant::ProcessMonitorImpl::
    ObserveProcess(std::__1::basic_string const&, opera::assistant::
    ProcessMonitor::Observer*)
  - DNA-79558 Add database for continue shopping feature
  - DNA-79560 Create hidden runtime flag #continue-shopping
  - DNA-79702 Create Continue Shopping service
  - DNA-79786 Fix database backend for deleting the partner offer
  - DNA-80193 Magnifying glass icon doesn’t match the search box
    boundaries in settings and extensions
  - DNA-80237 Prevent data collection when feature is off
  - DNA-80244 Introduce another feature flag for changing
    the default value of folded state
  - DNA-79558 Add database for continue shopping feature
  - DNA-79560 Create hidden runtime flag #continue-shopping
  - DNA-79702 Create Continue Shopping service
  - DNA-79786 Fix database backend for deleting the partner offer
  - DNA-80193 Magnifying glass icon doesn’t match the search box
    boundaries in settings and extensions
  - DNA-80237 Prevent data collection when feature is off
  - DNA-80244 Introduce another feature flag for changing the default
    value of folded state
  - DNA-79560 Create hidden runtime flag #continue-shopping
  - DNA-79702 Create Continue Shopping service
  - DNA-79786 Fix database backend for deleting the partner offer
  - DNA-80193 Magnifying glass icon doesn’t match the search box
    boundaries in settings and extensions
  - DNA-80237 Prevent data collection when feature is off
  - DNA-80244 Introduce another feature flag for changing the default
    value of folded state
  - DNA-79063 Address bar icons are hardly visible in private window in
    light mode
  - DNA-79274 No warning notification on quitting Opera with multiple
    tabs open after update
  - DNA-80103 Investigate best ICECC_THREADS for faster Mac builds
  - DNA-80105 O63 translations (08.08.2019)
  - DNA-80219 DCHECK at ExtensionDownloader::HandleManifestResults
  - DNA-80330 [My Flow] The QR code and connection code is not visible
    for some people
  - DNA-79569 Don’t provide default value for titleTextColor in
    opr.wallpapersAPI
  - DNA-80221 Change channel to “stable” in permissions features for
    wallpapersPrivate
  - DNA-80230 Promote O63 to stable
* Tue Aug 13 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to version 62.0.3331.116
  - CHR-7498 Update chromium on desktop-stable-75-3331
    to 75.0.3770.142
  - DNA-78224 Sidebar buttons for internal pages not working on
    internal pages
  - DNA-78291 [Mac] Unable to move detached developer tool window
  - DNA-78385 [MacOS] Pinned communicators are not visible in
    full-screen mode
  - DNA-78502 Reload page button on toolbar doesn’t work on Mac
  - DNA-79274 No warning notification on quitting Opera with
    multiple tabs open after update
  - DNA-79753 Bookmark manager doesn’t open in private mode
  - DNA-79882 Control search box styling dynamically
  - DNA-80009 Use lowercase for search country matching
* Fri Jul 26 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to version to 62.0.3331.99
  - DNA-78392 [Mac] Crash when trying to change theme in easy setup
  - DNA-79205 [Mac] Dev tools in separate window – the bottom of
    the page isn’t visible
  - DNA-79391 Show Easy Setup panel with API from welcome/upgrade
    page
  - DNA-79434 Crash at opera::BrowserSidebarErrorPage::
    BrowserSidebarErrorPage(content::WebContents*, Browser*, GURL const&)
  - DNA-79456 Revert removing BB for new users
  - DNA-79489 [Mac] “Show warning before quitting with ⌘Q” flag
    is disabled after browser restart
* Wed Jul 17 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to version to 62.0.3331.66
  - DNA-77821 Parse the specification file
  - DNA-77946 Create the hints service – update & read the hint
    specification file from the profile
  - DNA-78342 Crash at opera::BrowserSidebarErrorPage::
    ~BrowserSidebarErrorPage()
  - DNA-79178 Crypto Wallet welcome/pairing page – string
    modification
  - DNA-79229 Translation: Crypto Wallet welcome/pairing page –
    string modification [PL, DE, RU]
* Fri Jul  5 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to version 62.0.3331.43
  - CHR-7446 Update chromium on desktop-stable-75-3331
    to 75.0.3770.100
  - DNA-78285 [Mac] Dragging URL from Address Field to
    Bookmarks Bar Freezes Opera
  - DNA-78290 Adapt CryptoWallet welcome / pairing page to
    Opera Touch for iOS
  - DNA-78557 [Linux] OSCrypt is not initialized before being
    used in crypto wallet
  - DNA-78575 [Win7] Arrows are not visible
  - DNA-78921 Allow to use ES imports on Settings page
  - DNA-78983 columns misaligned in the Manage Search Engines
    in the opera://settings
  - DNA-79014 Folder blinks when selecting different folders in
    opera://bookmarks
  - DNA-79076 Enable #crypto-wallet-ios-instructions on O62
  - DNA-79081 [Mac] Adding/removing elements from sidebar makes
    it broken
  - DNA-79175 Update tools/clang/scripts/update.py to
    version from M76
* Sat Jun 29 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to version 62.0.3331.18
  * DNA-78204 Unable to run Opera again after closing it with
    snapshot opened
  * DNA-79036 Promote O62 to stable
- Complete Opera 62.0 changelog at:
  https://blogs.opera.com/desktop/changelog-for-62/
* Sun Jun 16 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to version 60.0.3255.170
  * DNA-77132 [Mac] Highlight visible when closing a tab
  * DNA-77356 [Mac] Tabs hovered state doesn’t go away
  * DNA-77676 [Mac] Hover state stays after closing tab
  * DNA-77858 News section display a tiny part of an article image
  * DNA-77962 Zombie received -currentTab
  * DNA-78285 [Mac] Dragging URL from Address Field to
    Bookmarks Bar Freezes Opera
  * DNA-78395 Add browser test covering this feature
* Mon Jun 10 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to version 60.0.3255.151
  * DNA-77160 [Dark] Extension bar in dark theme
  * DNA-77290 [mac mojave] not possible to minimize Opera if
    it’s inactive application
  * DNA-77522 Add “Use bigger tiles” option to Settings page
  * DNA-77917 [Mac] Tab views get leaked
  * DNA-78279 Options for personal news in settings are missing
  * DNA-78346 Crash at service_manager::
    Main(service_manager::MainParams const&)
  * DNA-78362 ‘Check failed: mtime_result’ during
    desktop_common_unittests
* Thu May 30 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to version 60.0.3255.109
  * DNA-78037 Crash at
    base::Time::Explode(bool, base::Time::Exploded*)
  * DNA-77416 Layout doesn’t align well when dynamically changing
    tile size
  * DNA-77466 Cancel button for not now context menu
  * DNA-77558 Create browser tests
  * DNA-77745 [Mac] Maximized Opera window expands after watching
    a video in fullscreen
  * DNA-78037 Crash at
    base::Time::Explode(bool, base::Time::Exploded*)
  * DNA-78085 Uncaught exception in background worker
  * DNA-78114 Update schema version on desktop-stable-73-3255
* Fri May 17 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to version 60.0.3255.95
  * DNA-76715 [Mac] Unable to open context menu with ctrl + click
    on inactive tab
  * DNA-76725 Highlight of elements differ between Omenu and Tabmenu
  * DNA-76820 RulesCacheTest.ShouldDownloadNotExistingRules is flaky
  * DNA-76933 Crash at views::Widget::CloseWithReason
    (views::Widget::ClosedReason)
  * DNA-77431 [Mac] Favicon of active tab “moves” when opening new tab
  * DNA-77702 Default startpage wallpaper renders very slowly if
    you don’t have hardware acceleration
  * DNA-77963 Crash at base::Value::GetDouble()
* Mon May  6 2019 seanlew@opensuse.org
- Update to version 60.0.3255.70
  * DNA-75464 Crash at base:Time::Explode
  * DNA-769O9 Crash at views::BridgedNativeWidgetlmpl
  * DNA-76938 Rate Opera - black text/gray background
  * DNA-77341 Extensions action should be hidden in overflow menu
  * DNA-77346 Use bigger tiles after update to R3
  * DNA-77361 Crash at opera::PageView::islocked()
  * DNA-7739O Previous wellpaper color blinks when focusing tab
  * DNA-774O3 Tailor font size for fallback tiles
  * DNA-77545 Opera crashes when trying to create snap
* Mon Apr  1 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to version 58.0.3135.128
  * DNA-75464 Crash at base::Time::Explode(bool, base::Time::
    Exploded*)
  * DNA-76306 Prevent shutdown/automatic/manual metric sending when
    no UUID is present
  * DNA-76412 Crash at opera::stats::SessionsTabHelper::
    DidFinishNavigation(content::NavigationHandle*)
  * DNA-76645 [Mac 10.14] Closing background windows closes all
    windows
  * DNA-76662 Crash at url::Parsed::Parsed(url::Parsed const&)
  * DNA-76760 Backport the latest sessions schema to 58
* Sat Mar 23 2019 Sean Lewis <seanlew@opensuse.org>
- Update to version 58.0.3135.118
  * DNA-76663 Opera crashes when Speed Dial suggestions refresh
* Sun Mar  3 2019 Carsten Ziepke <kieltux@gmail.com>
- Update to version 58.0.3135.79
  * DNA-60640 [All OS] ExtensionThemesPrivateApiTest.SetCurrent fails
  * DNA-75726 Crash at opera::StartPagePreloadService::GetStartPage()
  * DNA-75728 Crash at non-virtual thunk to opera::SearchCopyPopupView
    ::ButtonPressed(views::Button*, ui::Event const&)
  * DNA-75845 opera://about/credits not scrollable
* Sat Feb 23 2019 seanlew@opensuse.org
- Update to version 58.0.3135.68
  * DNA-75461 Extend Yandex Zen coverage by Belarus and Kazakhstan
* Mon Feb 18 2019 seanlew@opensuse.org
- Update to version 58.0.3135.65
  * DNA-73673 Crash at extensions::Extension:location()
  * DNA-73865 Incorrect temp dir used
  * DNA-74035 standalone update uses incorrect temp dir
  * DNA-74689 Text highlight becomes gray after selection
  * DNA-74862 Search copy popup visible after opening new ext tab
  * DNA-75024 Proxy auth dialog blocks onAuthRequired event
* Thu Jan 24 2019 seanlew@opensuse.org
- Update to version 58.0.3135.47
  * DNA-74542 Record the feature value for DNA-74540
  * DNA-74960 Promote O58 to Stable
* Fri Jan 11 2019 seanlew@opensuse.org
- Update to version 57.0.3098.116
  * DNA-71854 Linux crash with older versions of NSS
  * DNA-73213 Bookmark bar drop indicator is visible
  * DNA-74571 Start page is opened after restart with some pages
  * DNA-74744 In-house translations of "Display the start page"
* Fri Jan  4 2019 sean@suspend.net
- Update to version 57.0.3098.110
  * DNA-74142 RSS does not load
  * DNA-74478 Add some info about first run logic to crash logs
* Mon Dec 24 2018 sean@suspend.net
- Update to version 57.0.3098.106
  * DNA-70670 Internal error pages miss error code info
  * DNA-73057 Crash fixes
  * DNA-74364 Zen news notification doesn't disappear
  * DNA-74531 Use Discover servers by default
  * DNA-74542 Record the feature value for DNA-74540
  * DNA-74503 [SECURITY] Magellan vuln fix
* Sat Dec 15 2018 sor.alexei@meowr.ru
- Update to version 57.0.3098.102 (changes since 57.0.3098.76):
  * Crash on exit when add to bookmarks popup opened and window closed.
  * Start page elements state (enabled/disabled).
  * Crash at
    extensions::`anonymous namespace”::ExternalWindowHelper::FindAndCloseWindow.
  * Omnibox closes after middle-click on a suggestion.
  * Crash when cancelling dragging tab.
  * custom_partner_content.json is not created.
  * Switching news off and back on does not render content.
  * Prepare Campaign isyf for regular releases.
  * Crash at
    opera::content_filter::`anonymous namespace”::CaretMatches.
  * Improve Netflix tile hover animation.
  * Control Netflix notifications visibility by a pref.
  * Handle invalid sources format for scrollable section.
  * Allow to override the News version served from CDN.
  * Crash at BrowserProcessImpl::Unpin().
  * Crash at base::Value::Value(base::flat_map const&).
  * [O57] web3.js downloaded with flag disabled.
  * Fix performance problems with extensions blocking feature.
  * Disable official PiP (picture-in-picture) or implement a UI for
    it.
* Sat Dec  1 2018 sean@suspend.net
- Update to version 57.0.3098.76
  + DNA-73673 Crash at extensions::Extension::location()
  + DNA-73823 Deliver translations for notifications
  + DNA-73835 Installer doesn't start
  + DNA-73852 Get rid of unescaped '#' in body
  + DNA-73875 Don't change the option after upgrade
  + DNA-73931 [Netflix] 'Watch trailer' should be separate line
  + DNA-74013 Improve layout of user consent popup
  + DNA-74014 Show Netflix notification ASAP
  + DNA-74018 Set integer, not boolean pref in session startup pref
  + DNA-74024 Crash loop on startup with a clean profile
  + DNA-74042 Error message in Console after disable/enable News
  + DNA-74063 Promote O57 to stable stream
* Sat Nov 17 2018 sean@suspend.net
- Update to version 56.0.3051.104 (changes since 56.0.3051.99):
  * DNA-69051 [Mac] Crash at opera:hints::HintManager::RemoveObserver
  * DNA-73192 Promotion Banner Update
* Sun Nov 11 2018 sean@suspend.net
- Update to version 56.0.3051.99 (changes since 56.0.3051.31):
  * DNA-72644 extension desktop capture does not work properly
  * DNA-73176 cannot see full license text on opera://about/credits
  * DNA-73285 [Linux] no tab separator
  * DNA-73335 Crash at -[ZoomButton setAddressBarModel:]
  * DNA-73492 Coupon toolbar
* Mon Oct 22 2018 sor.alexei@meowr.ru
- Update to version 56.0.3051.52 (changes since 56.0.3051.31):
  * Crash at views::DialogDelegate::GetDialogClientView()
  * Crash at opera::partner_bookmarks::BookmarkData::operator=(opera::partner_bookmarks::BookmarkData&&)
  * Fix navbar getting strings from invalid source.
  * Wrong translation "Location" on Polish.
  * No hover on bookmarks bar directories.
  * [Dark mode] Suggestions in Search bar not visible.
  * Crash at -[ZoomButton isDefaultZoom].
  * Too much spacing between favicons on the bookmark bar.
* Thu Sep 27 2018 sor.alexei@meowr.ru
- Update to version 56.0.3051.31:
  * See https://blogs.opera.com/desktop/changelog-for-56/#b3051.31
* Mon Sep 24 2018 sor.alexei@meowr.ru
- Update to version 55.0.2994.61:
  * See https://blogs.opera.com/desktop/changelog-for-55/#b2994.61
* Thu Jun 28 2018 sor.alexei@meowr.ru
- Update to version 54.0.2952.41:
  * See https://blogs.opera.com/desktop/changelog-for-54/#b2952.41
* Thu Jun 21 2018 sor.alexei@meowr.ru
- Update to version 53.0.2907.106 (changes since 53.0.2907.37):
  * Update chromium on desktop-stable-66-2907 to 66.0.3359.170.
  * Make Alt+Space open web & bookmarks Instant Search.
  * ThemesTests.testAddThemeWithInvalidExtension fails.
  * Show PluginBlocked badge in address bar again if Flash is
    blocked on this page..
  * JS errors when dragging from Bookmarks Bar over Speed Dial on
    Start Page.
  * [IS] Some letters in page addresses are partially cut.
  * [Settings] Unable to put passphrase because advanced settings
    not reachable.
  * SleepDetectorService visible after closing Opera.
  * Sidebar hint cut off when sidebar is disabled.
  * Crash during closing bubble popup for instant search.
  * Instant search hint cut off for some languages.
  * Wrong search engine icon after switching modes.
  * Page views not reported for instant search.
  * Add tests for stats for page views.
  * Black rectangles shown in renderer.
  * Animated wallpaper playing music on O53.
  * Crash at base::win::`anonymous namespace”::ForceCrashOnSigAbort.
  * SDs can be doubled.
  * [Instant Search] Lack of translation for word "Space".
  * Window can’t be maximised completely.
  * SDs can be doubled.
  * Instant search dialogue is not focused when multiple tabs are
    opened.
  * [Synch] Names with more than 1024 chars are passed to server.
  * Port fix for CVE-2018-6148 to desktop-stable-66-2907.
  * SDs can be doubled.
  * SDs images are not refreshed.
  * Snapshot captures only currently visible area when scrolling.
  * Vietnamese: Missing translations.
* Thu May 10 2018 sor.alexei@meowr.ru
- Update to version 53.0.2907.37:
  * See https://blogs.opera.com/desktop/changelog-for-53/#b2907.37
* Fri Mar 23 2018 sor.alexei@meowr.ru
- Update to version 52.0.2871.30:
  * See https://blogs.opera.com/desktop/changelog-for-52/#b2871.30
- AppStream file standard updates.
- Install the .desktop file as com.opera.opera.desktop to comply
  with freedesktop.org standards.
- Change the package licence from SUSE-NonFree to NonFree.
* Thu Mar 15 2018 kieltux@gmail.com
- Update to version 51.0.2830.55:
  * See https://blogs.opera.com/desktop/changelog-for-51/#b2830.55
* Sun Mar  4 2018 kieltux@gmail.com
- Update to version 51.0.2830.40:
  * See https://blogs.opera.com/desktop/changelog-for-51/#b2830.40
* Thu Feb  8 2018 sor.alexei@meowr.ru
- Update to version 51.0.2830.26:
  * See https://blogs.opera.com/desktop/changelog-for-51/#b2830.27
* Tue Jan 30 2018 sor.alexei@meowr.ru
- Update to version 50.0.2762.67:
  * Re-enable VPNTests.testCountryChangingDifferentWindows when
    SVC-1396 and SVC-1395 are done.
  * Fix "Spectre" vulnerability check failing.
  * Fix cache 404 response from SD suggestions thumbnail generator.
  * Fix SD server suggestions not cached until suggestions strip is
    shown.
  * Fix a crash at
    opera::installer::association_utils::`anonymous namespace”::GetApplicationAssociationRegistrationInternal.
* Sat Jan 20 2018 kieltux@gmail.com
- Update to version 50.0.2762.58:
  * Bookmarks bar is shown upon update to O50.
  * Fix blank history, white StartPage.
  * Chromium was updated to 63.0.3239.132.
* Thu Jan  4 2018 sor.alexei@meowr.ru
- Update to version 50.0.2762.45:
  * See https://blogs.opera.com/desktop/changelog-for-50/#b2762.42
* Fri Dec 29 2017 sor.alexei@meowr.ru
- Update to version 49.0.2725.64:
  * VPN "Select virtual location" translations.
  * Fix Opera O49 not working with chromium-codecs-ffmpeg-extra
    version 63.
* Sun Dec 17 2017 sor.alexei@meowr.ru
- Update to version 49.0.2725.56:
  * Shift-clicking reload should force-reload the page but it also
    opens a tab.
  * Changes to opera:about translations.
  * Integrate translations for new virtual locations.
  * CreditCardSaveManagerTest failures in smoketests.
  * Add a Santa emoticon to Snaptool.
* Sat Nov 18 2017 sor.alexei@meowr.ru
- Update to version 49.0.2725.39:
  * Fix a crash at
    opera::StatsServiceImpl::StartNewLog(base::Callback).
* Wed Nov  8 2017 sor.alexei@meowr.ru
- Update to version 49.0.2725.34:
  * See https://blogs.opera.com/desktop/changelog-for-49/#b2725.34
* Fri Oct 27 2017 sor.alexei@meowr.ru
- Update to version 48.0.2685.52:
  * Allow Ctrl+C when capturing the screen to copy what’s marked.
  * Take a snapshot from the surface for PDF viewer snaps.
* Thu Oct 19 2017 sor.alexei@meowr.ru
- Update to version 48.0.2685.50:
  * See https://blogs.opera.com/desktop/changelog-for-48/#b2685.50
* Tue Sep 12 2017 sor.alexei@meowr.ru
- Exclude libGLESv2.so from RPM requirements (boo#1058188).
* Tue Aug 29 2017 luc14n0@linuxmail.org
- Update to version 47.0.2631.55:
  * Full changelog: https://blogs.opera.com/desktop/changelog-for-47/#b2631.55
* Thu Jul 27 2017 kieltux@gmail.com
- Update to version 46.0.2597.57:
  * Full changelog available at:
    https://blogs.opera.com/desktop/changelog-for-46/#b2597.57
* Thu Jul 13 2017 sor.alexei@meowr.ru
- Update to version 46.0.2597.46:
  * Fix white frame around a PDF file.
  * UTF encoding problems in installation_status.xml in China –
    results in uninstallation and AU errors.
* Fri Jun 30 2017 kieltux@gmail.com
- Update to version 46.0.2597.32:
  * Full changelog available at:
    https://blogs.opera.com/desktop/changelog-for-46/#b2597.32
* Fri Jun 23 2017 sor.alexei@meowr.ru
- Update to version 46.0.2597.26:
  * See https://blogs.opera.com/desktop/changelog-for-46/#b2597.26
- Switch to unpacking RPM.
- Recommend flash-player-ppapi instead of chromium-pepper-flash.
* Tue Jun 20 2017 kieltux@gmail.com
- Update to version 45.0.2552.898:
  * Full changelog available at:
    https://blogs.opera.com/desktop/changelog-for-45/#b2552.898
* Mon Jun  5 2017 kieltux@gmail.com
- Update to version 45.0.2552.888:
  * Full changelog available at:
    https://blogs.opera.com/desktop/changelog-for-45/#b2552.888
* Sat May 27 2017 kieltux@gmail.com
- Update to version 45.0.2552.881:
  * Full changelog available at:
    https://blogs.opera.com/desktop/changelog-for-45/#b2552.881
* Tue May  9 2017 sor.alexei@meowr.ru
- Update to version 45.0.2552.635:
  * See https://opera.com/blogs/desktop/changelog-for-45
* Sat Apr 29 2017 kieltux@gmail.com
- Update to version 44.0.2510.1449:
  * Full changelog available at:
    https://www.opera.com/blogs/desktop/changelog-for-44/#b2510.1449
* Sun Apr 16 2017 kieltux@gmail.com
- Update to version 44.0.2510.1218:
  * Full changelog available at:
    https://www.opera.com/blogs/desktop/changelog-for-44/#b2510.1218
* Sun Apr  9 2017 kieltux@gmail.com
- Update to version 44.0.2510.1159:
  * Full changelog available at:
    https://www.opera.com/blogs/desktop/changelog-for-44/#b2510.1159
* Sat Mar  4 2017 kieltux@gmail.com
- Update to version 43.0.2442.1144:
  * Full changelog available at:
    https://www.opera.com/blogs/desktop/changelog-for-43/#b2442.1144
* Wed Feb 22 2017 danny.al-gaaf@bisect.de
- Update to version 43.0.2442.991
* Tue Feb  7 2017 sor.alexei@meowr.ru
- Update to version 43.0.2442.806:
  * See https://opera.com/blogs/desktop/changelog-for-43
* Sun Jan 29 2017 kieltux@gmail.com
- Update to version 42.0.2393.517:
  * Full changelog available at:
    https://www.opera.com/blogs/desktop/changelog-for-42/#b2393.517
* Sat Jan 21 2017 kieltux@gmail.com
- Update to version 42.0.2393.137
  * [Linux] Chinese websites are not readable on Ubuntu 16.04
  * Notification setting icon doesn’t open notification exceptions
    settings
  * Firewall prompt triggered on start with media-router flag
    enabled
  * H264 video does not work on Linux
  * Unsorted Bookmarks are not visible
  * Unreported installer error when trying to install x64ver in
    other location that already installed x32ver
  * Add installer architecture *stats*
  * Update 360 build with preinstalled extension
* Sun Dec 25 2016 kieltux@gmail.com
- Update to version 42.0.2393.94:
  * Fix a crash in KeyStorageKeyring::GetKey.
  * Fix a rash at opera::BookmarkMenuDelegate.
  * Port Chromium's fix for a
    content::TextInputClientObserver::GetFocusedPepperPlugin
    crash to desktop-stable-55-2393.
  * Update Chromium to version 55.0.2883.87.
* Tue Dec 13 2016 sor.alexei@meowr.ru
- Update to version 42.0.2393.85:
  * No changelog available.
* Sun Nov 27 2016 kieltux@gmail.com
- Update to 41.0.2353.69:
  * Moving elements in bookmarks bar crashes Opera
* Sat Nov 19 2016 mailaender@opensuse.org
- Add appdata.xml for https://software.opensuse.org/appstore
* Thu Nov 10 2016 kieltux@gmail.com
- Update to 41.0.2353.56:
  * Crash on refreshing of tooltip text when deleting a bookmarks
    bar bookmark in folder menu
  * Crash if host player closed right after opening detached
    video
  * Weird animation when opening a tab with middle-click when
    there’s tabs to the right of the active one already
  * Detached video is white for few seconds after detaching
  * On any page refresh, the video popout closes
  * Keyboard input breaks after right clicking / mouse gesturing
    on detached video
  * Videopopout position not restored
  * [PN] Less articles than expected
  * [PN] Request: add fail-safes to discover api requesting code
  * [PN] XSS in Personalized Newsreader
  * Chromium has been updated to the 54.0.2840.87 version
* Tue Oct 25 2016 sor.alexei@meowr.ru
- Update to version 41.0.2353.46:
  * No changelog available.
* Fri Oct  7 2016 kieltux@gmail.com
- Update to 40.0.2308.81:
  * Whitelist some AV software certificates
  * Backspace in URL field navigates back in history
  * Opera 39 fails to import firefox bookmarks.
  * Broken tab bar and crash on dragging a tab while it loads
  * [Settings] Checkbox aligned to top of text
  * Transparent UI items in case DWM Accent Color key missing
  * ‘Show system color on top bar’ shouldn’t be visible if
    accent color cannot be determined.
  * Remove VPN ‘Coming soon’ – WP2
* Sat Sep 24 2016 sor.alexei@meowr.ru
- Change opera.sh to reflect how and when setuid sandboxing works
  (it is not required at all when kernel supports CLONE_NEWUSER).
* Thu Sep 22 2016 kieltux@gmail.com
- Update to 40.0.2308.62:
  * Alt+drag (text selection on links) opens O-menu
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to 40.0.2308.54:
  * No changelog available.
* Wed Sep 14 2016 kieltux@gmail.com
- Update to 39.0.2256.71:
  * Deadlock when closing a bubble opened by touch
  * Provide translations for additional
    (VPN-related strings) for O39
  * Crash in opera::FreedomProxyConfigurationImpl::
    RetrieveProxyServers
  * [VPN] No temporary or permanent error when unable
    to connect to API server
  * Some requests bypass the proxy on startup (again)
  * [Linux] Hints are cut off if they fall outside the main window
  * SE-Proxy-Authorization header revealed for HTTPS
  * Whitelist some AV software certificates
  * Store custom user agent postfix in registry
* Thu Aug  4 2016 sor.alexei@meowr.ru
- Update to version 39.0.2256.48.
* Sun Jul 10 2016 kieltux@gmail.com
- Update to 38.0.2220.41:
  * Hovering bookmark below Menu crashes Opera
  * [SP] Quick clicking side panel items fails to work
  * Bold text in address bar suggestions is wrongly displayed
  * Certain pages never load completely when AdBlocker is on
  * The silent mode – fall back to Current User installation.
  * Youtube history again not being filled if ad-blocker is enabled
  * [Engine] Problems with autocomplete when typing www
  * Adblock + speedtest.net = blank page
  * YouTube shows ‘fullscreen unavailable’ message if DPI is > 100%%
* Wed Jun  8 2016 kieltux@gmail.com
- Update to 38.0.2220.29:
  * Changelog is available at
    https://opera.com/blogs/desktop/changelog-38
* Mon Jun  6 2016 kieltux@gmail.com
- Update to 37.0.2178.54:
  * Detach button won’t be visible in fullscreen anymore DNA-53205.
  * Pop out video wont freeze anymore after moving source tab
    to separate window.
  * Security fixes as chromium is updated to version 50.0.2661.102.
* Wed May  4 2016 sor.alexei@meowr.ru
- Update to version 37.0.2178.32.
- Disable IA32 build as rpmlint has a memory error with it.
* Wed Apr 13 2016 kieltux@gmail.com
- Update to 36.0.2130.65:
  * HiDPI: page scrollbar too narrow.
  * Pinch to zoom is not working.
  * Crash in
    web_modal::WebContentsModalDialogManager::ShowDialogWithManager
    with simplified printing option.
  * Download resumption not working after restart.
  * Tabs page view sticks permanently when “Adjust Speed Dial
    animations for slower hardware” is enabled.
  * Tablet mode layout and tablet mode fullscreen button not
    working.
  * Chromium is updated to version 49.0.2623.110.
* Thu Apr  7 2016 sor.alexei@meowr.ru
- Exclude libffmpeg.so* and libfreetype.so* from provides and
  requires as these are bundled and shouldn't be populated
  (boo#974251).
* Wed Mar 30 2016 kieltux@gmail.com
- Update to 36.0.2130.46:
  * [Linux] Can’t play h264 videos
  * Crash when refreshing page with mouse locked sliding toolbar
    notification
  * Go to browser settings not translated to any language
  * User-deleted speed dials with an “added” field are re-added on
    browser update without DPC version change
* Tue Mar 15 2016 kieltux@gmail.com
- Update to 36.0.2130.32:
  * Better touch support and some interface tweaks
    for Windows 10 users.
  * Hidden sync button when signed in without any problems.
  * Faster and more stable transitions between internal pages.
  * Updated support for the latest Chromium/Blink release,
    version 49.
  * Stability enhancements and bug fixes.
* Wed Mar  2 2016 kieltux@gmail.com
- Update to 35.0.2066.92:
  * Opera stops responding/freezes on various sites on
    Windows 10.
  * Monitor won’t go sleep when Opera has animated theme.
  * [Linux] Mosaic of tab bar artifacts instead of Web UIs
    when hardware accelerated.
* Mon Feb 22 2016 sor.alexei@meowr.ru
- Update to 35.0.2066.82.
* Fri Feb 19 2016 kieltux@gmail.com
- Update to 35.0.2066.68:
  * New window is not fully opened after previous was minimised.
  * Windows size ignored after AU – Opera always opens maximised.
* Mon Feb  1 2016 sor.alexei@meowr.ru
- Update to 35.0.2066.37.
- Add x86-32 build target.
* Sun Jan 24 2016 kieltux@gmail.com
- Update to 34.0.2036.50:
  * [Linux] Netflix will not play
  * Browser hangs, without crash when using Turbo
* Thu Jan 14 2016 sor.alexei@meowr.ru
- Update to 34.0.2036.47:
  * [Engine] Crash in HttpRequestHeaders::AddHeadersFromString.
  * “Mute tab” in context menu, despite flag being disabled by
    default in O34.
  * Turbo badge similar to history badge.
  * DeleteBrowserData not working need for maintenance of API.
  * Renderer crashes when trying to play a H.264 movie.
  * Issues with Montenegrin language.
  * Wrong aspect ratio on Netflix videos.
* Tue Dec  8 2015 sor.alexei@meowr.ru
- Update to 34.0.2036.25.
* Tue Nov 17 2015 baiduzhyi.devel@gmail.com
- Update to version 33.0.1990.115.
* Fri Nov 13 2015 sor.alexei@meowr.ru
- Update to 33.0.1990.58.
* Tue Oct 27 2015 sor.alexei@meowr.ru
- Update to 33.0.1990.43.
* Tue Sep 29 2015 baiduzhyi.devel@gmail.com
- Update to version 32.0.1948.69.
* Tue Sep 15 2015 sor.alexei@meowr.ru
- Update to 32.0.1948.25.
* Tue Aug 18 2015 baiduzhyi.devel@gmail.com
- Update to version 31.0.1889.174.
* Tue Aug  4 2015 baiduzhyi.devel@gmail.com
- Update to version 31.0.1889.99.
* Tue Jul 14 2015 baiduzhyi.devel@gmail.com
- Update to version 30.0.1835.125.
* Thu Jun 25 2015 baiduzhyi.devel@gmail.com
- Update to version 30.0.1835.88.
* Mon Jun 15 2015 baiduzhyi.devel@gmail.com
- Update to version 30.0.1835.59.
* Tue Jun  9 2015 sor.alexei@meowr.ru
- Update to 30.0.1835.52.
* Thu May 21 2015 sor.alexei@meowr.ru
- Update to 29.0.1795.60:
  * Update to Chromium 42.0.2311.152.
* Tue Apr 28 2015 sor.alexei@meowr.ru
- Update to 29.0.1795.47.
* Thu Apr  9 2015 sor.alexei@meowr.ru
- Update to 28.0.1750.51:
  * Chromium update to 41.0.2272.118.
  * Fix crash on initiation HiDPI.
  * HiDpi detection did not work.
* Tue Mar 10 2015 sor.alexei@meowr.ru
- Update to 28.0.1750.48.
- Remove operaprefs_fixed.ini as it's no longer possible to
  configure Opera preferences globally like that.
- Remove i586 support as upstream did.
- Don't provide browser(npapi): Opera does not support NPAPI.
- Remove opera-gtk, and opera-kde4 as Opera now uses only Aura
  which is not detachable.
- Do not enable sandboxing by default as it requires SUID to root.
- Recommend PepperFlash and ffmpeg packages as they extend
  multimedia functionality (Flash and H.264/MP3 support).
* Sun Feb  9 2014 mailaender@opensuse.org
- Update to 12.16
  * Security Fixes:
  - Replaced code signing certificate
* Sat Apr  6 2013 tittiatcoke@gmail.com
- Update to 12.15
  * Bugfixes:
  - Fixed an issue where the search bar's default engine could
    be overridden by third-party apps
  * Security Fixes:
  - Added safeguards against attacks on the RC4 encryption
    protocol
  - Fixed an issue where cookies could be set for a top-level
    domain
* Thu Feb  7 2013 tittiatcoke@gmail.com
- Update to 12.14
  * fixes crash when checking for extension updates
- Introduce full URL's to the source files.
* Fri Feb  1 2013 idonmez@suse.com
- Remove update checker application since we don't need it.
  This removes the curl dependency as a bonus.
* Thu Jan 31 2013 tittiatcoke@gmail.com
- Update to 12.13
  * Recommended upgrade (security and stability enhancements)
  * Genaral and User Interface
  * Fixed an issue where Opera gets internal communication errors
    on Facebook
  * Fixed an issue where no webpages load on startup, if Opera is
    disconnected from the Internet
  * Fixed an issue where images will not load after back
    navigation, when a site uses the HTML5 history API
  * Security
  * Fixed an issue where DOM events manipulation might be used to
    execute arbitrary code
  * Fixed an issue where use of SVG clipPaths could allow
    execution of arbitrary code
  * Fixed an issue where CORS requests could omit the preflight
    request
* Tue Dec 18 2012 tittiatcoke@gmail.com
- Update to 12.12
  * Fixes and Stability Enhancements
  - New option ‘Delete settings and data for all extensions’
    option (off by default) in the Delete Private Data dialog
  - Corrected an issue where using the 'Delete Private Data'
    dialog could delete extension and settings data
  - Redesigned the 'Delete Private Data' dialog to be more usable
    with small screens
  - Fixed an issue where quitting Opera while in fullscreen mode
    could cripple the interface on the next start-up
  - Fixed an issue where malformed GIF images could allow
    execution of arbitrary code
  - Fixed an issue where repeated attempts to access a target
    site could trigger address field spoofing
  - Fixed an issue where private data could be disclosed to other
    computer users, or be modified by them
* Tue Nov 20 2012 tittiatcoke@gmail.com
- Update to 12.11
  * Bug fixes
  * Stability and Security improvement
* Fri Nov 16 2012 dliang@suse.com
- Add the icon cache update to the spec file (bnc#783934)
* Tue Nov  6 2012 tittiatcoke@gmail.com
- update to 12.10
  * Improved extensions
  * Support for SPDY, CSS3 Gradients, Transitions, Animations, and Transforms
  * Support for WebSockets
  * Fullscreen and Page Visibility API
  * ICC Profiles support
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unified/1210/
* Thu Aug 30 2012 lijewski.stefan@zabka.pl
- update to 12.02
  * Fixed an issue where truncated dialogs may be used to trick users
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1202/
- fixes [bnc#778087]
* Thu Aug  2 2012 lijewski.stefan@zabka.pl
- update to 12.01
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1201/
- fixes [bnc#774191]
* Thu Jul 26 2012 lijewski.stefan@zabka.pl
- rename to README.openSUSE
* Mon Jul 16 2012 lijewski.stefan@zabka.pl
- add README-opensuse note about operapref in file
- mark operaprefs_fixed.ini as config
* Wed Jul  4 2012 lijewski.stefan@zabka.pl
- fixes [bnc#769389]:
    added global prefs file disabling opera internal
    update mechanism
- use opera provided install script
* Mon Jun 18 2012 lijewski.stefan@zabka.pl
- update to 12.00
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1200/
- fixes [bnc#767045]
* Fri May 11 2012 lijewski.stefan@zabka.pl
- update to 11.64:
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1164/
- fixes [bnc#761633]
* Thu Apr 26 2012 lijewski.stefan@zabka.pl
- update to 11.62:
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1162/
- fixes [bnc#754687], CVE-2012-1924,CVE-2012-1925,CVE-2012-1926,
  CVE-2012-1927,CVE-2012-1928,CVE-2012-1929CVE-2012-1930,
  CVE-2012-1931
* Mon Mar  5 2012 vdziewiecki@suse.com
- add Provides: browser(npapi) FATE#313084
* Sun Feb  5 2012 aj@suse.de
-  Set license to SUSE-NonFree.
* Fri Jan 27 2012 lijewski.stefan@zabka.pl
- updated to 11.61
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1161/
- fixes [bnc#743079]
* Wed Dec  7 2011 prusnak@opensuse.org
- updated to 11.60
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1160/
* Thu Oct 20 2011 prusnak@opensuse.org
- updated to 11.52
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1152/
* Sat Sep  3 2011 lijewski.stefan@gmail.com
- updated to 11.51
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1151/
* Wed Jul  6 2011 lijewski.stefan@gmail.com
- updated to 11.50
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1150/
- fixes CVE-2011-1337, CVE-2011-2609 - CVE-2011-2627 [bnc#703668]
* Wed Jul  6 2011 lijewski.stefan@gmail.com
- updated to 11.15
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1150/
- fixes [bnc#703668]
* Wed May 18 2011 prusnak@opensuse.org
- updated to 11.11
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1111/
- fixes [bnc#694567]
* Tue Apr 12 2011 prusnak@opensuse.org
- updated to 11.10
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1110/
* Thu Feb  3 2011 prusnak@opensuse.org
- updated to 11.01
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1101/
- fixes [bnc#667639], CVE-2011-0681 - CVE-2011-0687
* Thu Dec 16 2010 prusnak@opensuse.org
- updated to 11.00
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1100/
- fixes [bnc#659882]
- drop ppc build as upstream is not creating packages anymore
* Sun Oct 24 2010 prusnak@opensuse.org
- subpackages (gtk,kde4) should require main package
* Tue Oct 12 2010 prusnak@opensuse.org
- updated to 10.63
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1063/
* Tue Oct 12 2010 prusnak@opensuse.org
- updated to 10.62
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1062/
* Mon Aug 30 2010 prusnak@opensuse.org
- split off gtk and kde4 engines [bnc#635360]
* Mon Aug 23 2010 prusnak@opensuse.org
- updated to 10.61 (build 6430)
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1061/
  * fixes [bnc#630771]
* Wed Jul  7 2010 prusnak@opensuse.org
- updated to 10.60 (build 6386)
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1060/
  * fixes [bnc#583620] [bnc#607823] [bnc#615942]
* Mon Nov 23 2009 prusnak@suse.cz
- updated to 10.10 (build 4742)
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1010/
* Mon Nov  2 2009 prusnak@suse.cz
- updated to 10.01 (build 4682)
  * full changelog available at:
    http://www.opera.com/docs/changelogs/unix/1001/
* Tue Sep  1 2009 prusnak@suse.cz
- updated to 10.00 final (build 4585)
  * full changelog available at:
    http://my.opera.com/desktopteam/blog/opera-10-goes-final
- replaced icons with upstream ones
- hopefully closes bugs [bnc#491876], [bnc#514728], [bnc#522940]
* Tue Aug 25 2009 prusnak@suse.cz
- updated to 10.00 rc (build 4570)
  * full changelog available at:
    http://my.opera.com/desktopteam/blog/2009/08/25/opera-10-0-release-candidate
* Thu Aug 13 2009 prusnak@suse.cz
- updated to 10.00 beta 3 (build 4538)
  * full changelog available at:
    http://my.opera.com/desktopteam/blog/2009/08/13/opera-10-0-beta-3
* Mon Aug 10 2009 prusnak@suse.cz
- updated to 10.00 (build 4529)
  * full changelog available at:
    http://my.opera.com/desktopteam/blog/2009/08/07/whats-with-the-red-dots-on-the-tabs
- use Qt4 build for x86 and x86_64 (no ppc Qt4 build yet)
* Thu Aug  6 2009 prusnak@suse.cz
- updated to 10.00 (build 4520)
  * full changelog available at:
    http://my.opera.com/desktopteam/blog/2009/07/31/tab-thumbnails-on-the-sides-and-opera-unite-improvements
* Wed Jul 22 2009 prusnak@suse.cz
- updated to 10.00 (build 4502)
  * full changelog available at:
    http://my.opera.com/desktopteam/blog/2009/07/21/new-snapshot-new-possibilities
* Thu Jul 16 2009 prusnak@suse.cz
- updated to 10.00 (build 4493)
  * lots of changes - full list is available at:
    http://my.opera.com/desktopteam/blog/2009/07/16/more-than-beta-2
- added download script (download.sh, to make updates easier)
* Mon Jul 13 2009 prusnak@suse.cz
- updated to 10.00 (build 4478)
  * lots of changes - full list is available at:
    http://my.opera.com/desktopteam/blog/2009/07/09/snapshot
* Mon Jun 15 2009 prusnak@suse.cz
- updated to 10.00 (aka build 4440)
  Opera Unite
  * a collaborative technology that uses a compact server inside
    the Opera desktop browser to share data and services
  User Interface
  * "Remove From Toolbar" and other toolbar customization options
    have been moved into a submenu.
  * The ability to reset toolbar customization has been added.
  * The search field can now be resized.
  Mail, News, Chat
  * A "delete after X number of days" facility has been added.
  * Mails can now have horizontal scrollbars.
  * Fixes have been made to mail compose.
  * The adding of links to HTML mails has been improved.
  * A recovery mechanism for corrupt mail databases has been added.
  * Feed progress which sometimes stuck on non-existent resources
    has been fixed.
  * Attachments in multipart/mixedpart of multipart/alternative mail
    are now correctly displayed.
  * When viewing a message, message subjects are now a text field
    again instead of a button.
  * Additional online feed readers have been added to the feed preview
    page.
  * Sent mail is now shown when using threading in the e-mail client.
  * A thread button has been added to the message list toolbar.
  * Keyboard shortcuts for Go to Thread (D), Watch Thread (Ctrl-D),
    and Ignore Thread (Ctrl-Shift-D) have been added.
  * The encoding mismatch dialog has been removed.
  Display and scripting
  * Full RGBA support is now included.
  * Basic Web font support has been added:
    o font specification (@font-face CSS rule) with the font-family
    descriptor that controls font choices
    o src descriptor with local and remote
    o Truetype (ttf) and Scalable Vector Graphics (svg) font support
  * Support has been added for the W3C Selectors API.
  * The objects returned by getClientRects() and getBoundingClientRect()
    have been renamed to ClientRectList and ClientRect instead of
    TextRectangle and TextRectangleList.
  * XMLHttpRequests will now trigger start-loading/end-loading events.
  * The proprietary window.setDocument method has been removed.
  * Support has been added for the SVGElement.currentFps and
    SVGElement.targetFps properties to read and control SVG
    frames per second.
  * The load event for scripts is now sent after the script is executed
    rather than before.
  * The load event is now sent to frame/iframe/object elements before
    it is sent to the document.
  * A highlight will no longer be added when HTMLElement.focus()
    is called unless keyboard navigation is already activated.
  Security
  * Support for TLS 1.2 has been added.
  * SSL v2 and weak cipher support have been completely removed.
  Miscellaneous
  * Opera now supports alpha transparent widget windows on Linux
    (rounded corners).
  * The painting of windowless plugins has been fixed.
  * A Java-related issue has been fixed.
  * Fixes have been applied to font fallback problems.
  * Opera no longer recognizes or supports the http://www.w3.org/TR/REC-html40
    namespace as an alias of http://www.w3.org/1999/xhtml.
  * Core fixes, including fixes for getElementsByClassName have been made,
    which should now work with multiple classes in className.
  * Regex \b is now correctly not matching the point between
    a letter and underscore.
  * Facebook chat has been fixed.
  * Image downloading has been improved.
  * Gmail problems have been solved.
  * Files generated by the Opera installer now use the same naming scheme
    across different platforms.
  * Support for UTF-32 encoding has been removed.
  * User JS files will now be executed in alphabetical order rather than file
    system order.
  * The first ID (instead of the last) is now used on pages with duplicate IDs
    when navigating to fragment IDs.
  * Support for the altGlyph element in SVGs has been added.
  * Support for 32-bit alpha in BMP and RLE-encoded BMP images has been added.
  * Several memory leaks have been plugged.
  * Several stability issues have been fixed.
  * Network access for widgets is now opt-in:
    o All existing widgets must be updated in order to have network access.
    o All widgets on widgets.opera.com have been given Internet access.
    o Network access is specified using the network attribute of the widget element:
    + Widgets that use <widget network="private"> will have Intranet access only.
    + Widgets that use <widget network="private public"> will have Intranet and Internet access.
- replaced icons with Tango version by Tomas Kebert
* Wed Mar  4 2009 prusnak@suse.cz
- updated to 9.64 (aka build 2480)
  * Security
  * Fixed an issue where specially crafted JPEG images could be used
    to execute arbitrary code, as reported by Tavis Ormandy
    of the Google Security Team; see our advisory
  * Fixed an issue where plug-ins could be used to allow cross
    domain scripting, as reported by Adam Barth; details will
    be disclosed at a later date.
  * Fixed a moderately severe issue; details will be disclosed
    at a later date.
  * Added Untrusted Rootstore Capability:
    o Opera downloads only the detailed information about
    untrusted (blacklisted) certificates when they are encountered
    o If download fails for certificate information in the list,
    Opera considers any certificate matching the ID as untrusted
  * Added version conditional fetching of certificate dependencies
    from an online repository
  * Fixed a problem downloading the CRL (Certificate Revocation List)
  * Fixed a problem that could cause SSL to deadlock in one state,
    hanging the connection
  * Fixed a problem that could cause the incorrect calculation
    of Certificate IDs
  * Implemented Extended Validation (EV) for cross-signed EV Root
    Certificates not shipped by default
  * Implemented preshipping of the Entrust 2048 CA (Certificate Authority)
  * Implemented Root Certificate fetching from an online repository
    when an intermediate matches a certificate in the repository
  * Improved support for weak encryption when importing .p12 private
    certificates
  * Prevented security information documents from being written to disk
  * Miscellaneous
  * Fixed a problem which created separate feed notifications;
    Opera now groups them together
  * Fixed a problem with the backspace key event in the Flash plug-in
  * Fixed a problem with inline find when no text was entered,
    and the Enter key was pressed
  * Fixed an instability error with the 64 bit Linux version
* Tue Dec 16 2008 prusnak@suse.cz
- updated to 9.63 (aka build 2474)
  * Opera Presto 2.1.1 user agent engine
  * Security
  * Manipulating text input contents can allow execution of
    arbitrary code, as reported by Red XIII. See our advisory.
  * HTML parsing flaw can cause Opera to execute arbitrary code,
    as reported by Alexios Fakos. See our advisory.
  * Long hostnames in file: URLs can cause execution of arbitrary
    code, as reported by Vitaly McLain. see our advisory.
  * Script injection in feed preview can reveal contents of
    unrelated news feeds, as reported by David Bloom. See our
    advisory.
  * Built-in XSLT templates can allow cross-site scripting, as
    reported by Robert Swiecki of the Google Security Team. See our
    advisory.
  * Fixed an issue that could reveal random data, as reported
    by Matthew of Hispasec Sistemas. Details will be disclosed
    at a later date.
  * SVG images embedded using <img> tags can no longer execute
    Java or plugin content, suggested by Chris Evans.
* Wed Nov 19 2008 prusnak@suse.cz
- define default fonts for better integration into desktop
* Thu Oct 30 2008 prusnak@suse.cz
- updated to 9.62 (aka build 2466)
  o Security
  * Fixed an issue where History Search could be used to execute
    arbitrary code, as discovered by Aviv Raff; see our advisory
  * The links panel no longer allows cross-site scripting;
    see our advisory
* Tue Oct 21 2008 prusnak@suse.cz
- updated to 9.61 (aka build 2456)
  o User Interface
  * Fixed an issue with Opera Link which could generate duplicate
    bookmarks during the synchronization process
  * The image toggle button on the status bar is now a normal button,
    and does not have a menu
  o Security
  * Fixed an issue where History Search could be used to reveal
    browsing history, as reported by Roberto Suggi Liverani of
    Security-Assessment.com; see our advisory
  * Fast Forward can no longer allow cross-site scripting,
    as reported by David Bloom; see our advisory
  * Prevented news feed preview from revealing the contents of unrelated
    news feeds, as reported by David Bloom; see our advisory
* Wed Oct  8 2008 prusnak@suse.cz
- updated to 9.60 (aka build 2444)
  o User Interface
  * Opera now remembers the bookmark panel position after restart
  * Added a setting opera:config#UserPrefs|ShowBookmarksInAddressfield-
    Autocompletion to prevent bookmarks from showing in the Address
    field auto-completion drop-down
  * When setting opera:config#TransferWindow|KeepEntriesDays to 0,
    Opera now removes the transfer history when restarting
  * Sites using HTTP Auth are now saved in typed history
  * Opera now stops loading pages with iframes when closing the page
    or pressing stop
  * Page encoding in site preferences can now be reset to automatic
  * Browsing Intranet sites now works after changing proxies in
    a running session
  * Improvements to Opera Link include the synchronization of search
    engines and typed history
  * Changed the default global history to 1000
  * Added a new default speedial.ini
  * Fixed sorting by progress in Transfers
  * Fixed copying of multiple entries from the history manager
  * Fixed a bug that could cause notes to be lost when using certain
    characters
  * Fixed dataloss situation when note folders had more than one line
    in their name
  * Fixed spurious highlighting when using the space character
    in inline find
  * Fixed an issue that would prevent links in frames from being opened
    by the keyboard
  o Mail, News, Chat
  * Added popular Chinese providers in mailproviders.xml
  * Made all top-level access points (except All Messages) selectable
  * Now copes better with broken POP servers that send empty UIDLs
  * The "Large font" setting is now respected for subjects
  * Cache files from feeds no longer show up in Transfers
  * Feeds are now detected even when served as text/html
  * Fixed the synchronization of removed labels for IMAP accounts
  * Fixed an issue where the signatures wouldn't change if the default
    account signature ended with a space
  * Fixed an issue where sent message bodies could disappear under
    certain circumstances
  * Fixed DCC transfers in IRC
  o Display and Scripting
  * Improved Acid3 support: The document property has been removed from
    iframe objects for compatibility with Gecko, WebKit, and the Acid3 test
  * Added support for the caller property on functions:
    http://developer.mozilla.org/En/Core_JavaScript_1.5_Reference:Global_Objects:Function:caller
  * Special characters are now displayed properly in the Address bar
    drop-down
  * Opera Dragonfly element highlighting no longer stays on the page
    after closing the developer tools window
  * Script focused elements are no longer highlighted
  * Fixed saving of SVG when right clicking
  * Fixed an issue where custom search engines would not get a favicon
  o Security
  * Verisign and Comodo are now formally EV-enabled: see Yngve's blog post
  * Fixed an issue where specially crafted addresses could execute
    arbitrary code, as reported by Chris of Matasano Security;
    see our advisory
  * Java applets can no longer be used to read sensitive information,
    as reported by Nate McFeters; see our advisory
  o Miscellaneous
  * Added the Opera Core version (currently "Presto/2.1.1")
    to the User Agent header
  * Improved performance with large wand.dat files
  * Fixed Fast Forward on Google search results pages
  o Unix-specific changes
  * Upgrading Opera on Debian no longer resets default x-www-browser
  * Fixed an issue where text with specified size suddenly disappears
    on Qt4 builds
* Wed Aug 20 2008 lmichnovic@suse.cz
- RC2 is final: adjusted version number
  - security fixes in opera 9.52:
  * Sites can no longer change framed content on other sites
  * Fixed an issue that could allow cross-site scripting
  * Custom shortcuts no longer pass the wrong parameters to
  applications, as reported by Michael A. Puls II
  * Prevented insecure pages from showing incorrect security
  information, as reported by Lars Kleinschmidt
  * Feed links can no longer link to local files
  * Feed subscription can no longer cause the wrong page address
  to be displayed
  - other stability upgrades and features (See Changelog)
* Fri Aug 15 2008 lmichnovic@suse.cz
- update to 9.52 RC2 build 2091
  * Added Help button to "Engine Init() Failed" error message on
  start-up to inform users about problem.
  * Fixed a problem with M&T Bank.
  * Fixed a problem with POP accounts where message bodies weren't
  downloaded.
  * Fixed a small memory leak in the BitTorrent code.
  * Added bookmark path to autocompleted bookmarks in the address
  bar to better distinguish them from visited pages.
  * Disabled APOP authentication for new accounts at online.no
  (not supported by them). Users experiencing problems with
  online.no account should switch to Plaintext authentication.
  * Fixed a crash that could occur when opening mail notification
  popups on a secondary monitor.
  * Fixed a few icon/skin issues.
  * Added a "Close Tab" entry to the File menu on Windows and Linux.
  * Fixed some translation errors.
* Fri Jul  4 2008 lmichnovic@suse.cz
- update to version 9.51
  * Lot's of security and bug fixes. See Changelog for more details.
- changing filehandler.ini inside spec file, erased external source
- erased external lang files cause they are included in the tarball
* Mon Jun 16 2008 lmichnovic@suse.cz
- security update to version 9.50 [bnc#400367]
  * Lot's of security and bug fixes and new features.
  See Changelog for more details.
- all archs (i386, ppc, x86_64) use shared qt3 library and gcc4
- enabled native 64bit build [bnc#204729]
- dropped sparc arch
- Opera now works with Flash plug-in also on 64bit [bnc#336213]
- deleted bugzilla-300536-oneclick.patch because file associations
  are rewritten manually in spec file
- applying bugzilla-208048-scim-qtimm-problem.patch for all archs
- deleted unused and obsolete extra file search.ini
- using AutopreReq on
* Wed Apr 30 2008 prusnak@suse.cz
- added hicolor opera icon [bnc#384209]
  * created by Aakash Soneri (http://www.akkasone.com/)
  * redistributed with written permission of the author
  * http://akkasone.deviantart.com/art/Opera-8-Browser-Icon-22991716
- registration file opera.reg no longer needed
- refactored spec file
* Thu Apr  3 2008 lmichnovic@suse.cz
- security update to 9.27 [bnc#376714]
  * Fixed an issue where newsfeed prompts could cause Opera to
  execute arbitrary code.
  * Solved an issue where resized canvas patterns could cause Opera
  to execute arbitrary code.
  * Improved keyboard handling of password inputs.
  * Fixed a BitTorrent transfer stability issue.
  * Resolved stablity issues with the Acid 3 test.
  * Additional stability fixes.
* Thu Feb 21 2008 lmichnovic@suse.cz
- security update to 9.26 [bnc#363574]
  * Fixed an issue where simulated text inputs could trick users
  into uploading arbitrary files.
  * Image properties can no longer be used to execute scripts.
  * Fixed an issue where the representation of DOM attribute values
  could allow cross site scripting.
  * Fixed a stability issue found in Opera 9.0 to 9.25, when Opera
  connects securely to Windows Server 2008 or other servers
    supporting the TLS Certificate Status extension.
  * Additional stability fixes.
* Fri Feb 15 2008 lmichnovic@suse.cz
- owning directories /usr/share/icons/hicolor/*/*
- added missing coreutils PreReq
- set Requires: on qt3 only for build with shared libs
* Wed Jan  2 2008 lmichnovic@suse.cz
- applying oneclick patch also on ppc arch
* Wed Jan  2 2008 lmichnovic@suse.cz
- security update to 9.25 [#350579]
  CVE-2007-6520, CVE-2007-6521, CVE-2007-6522, CVE-2007-6523,
  CVE-2007-6524
  * Fixed an issue where plug-ins could be used to allow cross
  domain scripting.
  * Fixed an issue with TLS certificates that could be used to
  execute arbitrary code.
  * Rich text editing can no longer be used to allow cross domain
  scripting.
  * Fixed a problem where malformed BMP files could cause Opera to
  temporarily freeze.
  * Prevented bitmaps from revealing random data from memory.
* Mon Oct 22 2007 lmichnovic@suse.cz
- security update to 9.24
  CVE-2007-5540, CVE-2007-5541 [#334832]
  * Fixed an issue where external news readers and e-mail clients
  could be used to execute arbitrary code
  * Fixed an issue where scripts could overwrite functions on pages
  from other domains.
- updated language files to meet the version [#331913]
* Thu Oct 18 2007 ro@suse.de
- don't build on x86_64, let's use the x86 version until we
  get something native
* Fri Aug 31 2007 ltinkl@suse.cz
- fix #300536 add one-click installation associations to opera
* Thu Aug 16 2007 ltinkl@suse.cz
- update to 9.23 (#300605 - VUL-0: opera: a specially crafted
  JavaScript can make Opera execute arbitrary code)
- #300536 - add one-click installation associations to opera
* Mon Jul 23 2007 lmichnovic@suse.cz
- update to 9.22 (#293101 VUL-0: opera 9.22 fixes double free bug)
  Crafted torrent files can execute arbitrary code; CVE-2007-2809
* Tue Jul 10 2007 ltinkl@suse.cz
- fix #289701 – old opera icons
* Thu Jul  5 2007 coolo@suse.de
- put desktop file into package and replaced references to the old
  icon
* Tue May 29 2007 ltinkl@suse.cz
- update to 9.21 fix release
- fix rpmlint warning about unsupported distro (8.20)
* Mon May  7 2007 ro@suse.de
- added unzip to buildrequires
* Wed Apr 18 2007 ltinkl@suse.cz
- update to 9.20 (#264218 - VUL-0: opera version 9.20 released)
* Wed Apr  4 2007 mfabian@suse.de
- Bugzilla #208048: add workaround to start script to avoid
  bad page layout in some locales when scim-qtimm is installed.
* Tue Jan  2 2007 ltinkl@suse.cz
- update to 9.10
* Sat Sep 30 2006 ltinkl@suse.cz
- fix #189635 - opera9 cannot be installed during system upgrade
- fix #208742 - VUL-0: opera: RSA signature forgery problem
- update to 9.02
* Wed Aug 16 2006 ltinkl@suse.cz
- #190137: incompatible language files in Opera 9.0-1.1 & Opera 9.0-1.3
* Thu Aug 10 2006 ltinkl@suse.cz
- #188632 - Opera 9.0 denial of service with A tag
* Tue Jun 27 2006 ltinkl@suse.cz
- update to 9.0 final
- #187716 - VUL-0: Opera jpeg integer overflow
- #176127 - /usr/share/pixmaps/opera.xpm and /usr/share/icons/opera.xpm are directories
* Thu May  4 2006 ltinkl@suse.cz
- fix #168288 - VUL-0: opera code exec via stylesheet (update to 8.54)
* Mon Feb 20 2006 ltinkl@suse.cz
- security update to 8.52 (#151788)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Dec 14 2005 ro@suse.de
- really use buildroot
* Tue Dec 13 2005 ltinkl@suse.cz
- add buildroot + norootforbuild
* Wed Nov 23 2005 ltinkl@suse.cz
- VUL-0: opera command line url shell command injection (#134905)
- update to 8.51
* Sat Sep 24 2005 ltinkl@suse.cz
- fix version number, really 8.50 :)
* Wed Sep 21 2005 ltinkl@suse.cz
- update to 8.05, fixing security issue #117980
* Thu Sep  1 2005 ltinkl@suse.cz
- go back to the stable version 8.02, register the version
  using the key kindly provided by Opera
* Tue Aug  2 2005 ltinkl@suse.cz
- update to 8.10 Preview
* Mon Jun 20 2005 ltinkl@suse.cz
- update to 8.01, fixing several security issues (#91179 and others)
* Mon May 23 2005 ltinkl@suse.cz
- major update to 8.0, all platforms
* Thu Feb 10 2005 ltinkl@suse.cz
- don't allow tricking the user into running arbitrary commands
  (#49218)
* Tue Oct  5 2004 ltinkl@suse.cz
- fix Netscape plugins (#46010)
* Wed Sep 15 2004 ltinkl@suse.cz
- x86 and ppc versions switched to dynamically linked against Qt (#43526)
- fix local file detection vulnerability (#43923)
- fix address bar spoofing vulnerability (#42279)
* Tue Sep 14 2004 kukuk@suse.de
- Remove OpenMotif1 and OpenMotif2 plugins [Bug #43311]
* Wed Aug 18 2004 ltinkl@suse.cz
- updated to 7.54
* Fri Jul 23 2004 ltinkl@suse.cz
- update to 7.53 (#42279)
* Fri Jul  9 2004 ltinkl@suse.cz
- update to 7.52
* Tue Jun  8 2004 ltinkl@suse.cz
- security bugfix update (#41628)
* Thu May 13 2004 ltinkl@suse.cz
- updated to 7.50 (all archs)
- threw away the now unused patch
* Mon Feb 23 2004 ltinkl@suse.cz
- updated to 7.23 for all archs
- updated the language files
- got rid of the motifwrapper hack
* Tue Sep 16 2003 aj@suse.de
- Remove broken requires.
* Thu Aug 28 2003 pthomas@suse.de
- Use the operamotifwrapper plugin from opera 7.20b as this
  is linked against the current libXm.so.3.
* Sat Aug 16 2003 adrian@suse.de
- install desktop file from kappfinder
* Fri Aug 15 2003 pthomas@suse.de
- Update ix86 and ppc to 7.11.
- Update sparc to 6.12 beta.
- Add most of the available language files.
* Wed Nov 13 2002 ro@suse.de
- comment out kde2 stuff
* Wed Aug 28 2002 uli@suse.de
- update -> 6.03 for i386 & compatibles
* Tue Aug 13 2002 ro@suse.de
- removed gnome1 support
* Fri Jul  5 2002 kukuk@suse.de
- Use %%ix86 macro
* Thu Jul  4 2002 sndirsch@suse.de
- added german help module (Bug #16341)
* Wed Jun  5 2002 stepan@suse.de
- patch install script to recognize hammer architecture.
* Wed May 29 2002 uli@suse.de
- update -> 6.01 (secfix)
* Mon May 27 2002 uli@suse.de
- added German localization from http://www.blauwal.at/opera
  (bug #16341)
* Wed May 15 2002 uli@suse.de
- update -> 6.0 final (x86 only)
* Fri Feb 22 2002 uli@suse.de
- update -> 6.0 (x86 only)
* Wed Jan 23 2002 ro@suse.de
- build using kde2-compat
- will need port to kde3 (icon pathes only)
* Mon Sep 17 2001 uli@suse.de
- initial package, x86/sparc/ppc only
